%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting default values        %
%          for the hyperparameters of the mean and variance      %
%          for the prior distribution of the parameters on       %
%          deterministic variables                               %
%                                                                %
%          Function: deterprior_dlg                              %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            h: handle to figure                      %
%                                                                %
%          This version:        April 4, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = deterprior_dlg(selector,curr_ini)

if strcmp(selector,'init')==1;
   tm.ini = curr_ini;
   tm.lambda_d = curr_ini.lambda_d;
   tm.old.lambda_d = curr_ini.lambda_d;
   tm.realscrsz = get(0,'ScreenSize');
   width = 500;
   height = 240;
else;
   deterprior_gui = findobj('Type','figure','Tag','DeterPriorDlg');
   deterprior_controls = get(deterprior_gui,'UserData');
   tm = get(deterprior_controls.apply,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      deterprior_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','deterprior_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','DeterPriorDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Hyperparameters - Prior for Parameters on Deterministics', ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','deterprior_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(deterprior_gui,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Deterministics',65,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Hyperparameters for Prior Distribution';
      desc_txt = 'The prior distribution for the parameters on the deterministic variables is Gaussian with common mean, zero covariances, and common variances determined by the deterministic shrinkage parameter. Press the "Apply" button to save your changes, the "Cancel" button to reset the values, and the "OK" button to finish.';
      deterprior_controls.icon = dialog_header_fcn([16 height-109 width-30 85],mirrorimage(maketrans(mycons.lambdabig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      deterprior_controls.icon = deterprior_controls.icon(1,1);
      
      axesbox([16 55 width-30 height-180],'Hyperparameters',82,[0.5 1]);
      
      %
      % create the header text and popup controls
      %
      
      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-170 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Deterministic shrinkage:', ...
         'Tag','LambdaDeterText');

      deterprior_controls.lambda_d = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-165 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',1, ...
         'Callback','deterprior_dlg deterministic', ...
         'String','0.01|0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00|1.05|1.10|1.15|1.20|1.25|1.30|1.35|1.40|1.45|1.50|1.55|1.60|1.65|1.70|1.75|1.80|1.85|1.90|1.95|2.00|2.10|2.20|2.30|2.40|2.50|2.60|2.70|2.80|2.90|3.00|3.25|3.50|3.75|4.00|4.25|4.50|4.75|5.00|5.50|6.00|6.50|7.00|7.50|8.00|8.50|9.00|9.50|10.00|15.00|20.00|25.00|30.00|35.00|40.00|45.00|50.00|55.00|60.00|65.00|70.00|75.00|80.00|85.00|90.00|95.00|100.00|105.00|110.00|115.00|120.00|125.00|130.00|135.00|140.00|145.00|150.00|155.00|160.00|165.00|170.00|175.00|180.00|185.00|190.00|195.00|200.00|210.00|220.00|230.00|240.00|250.00|260.00|270.00|280.00|290.00|300.00|325.00|350.00|375.00|400.00|425.00|450.00|475.00|500.00|550.00|600.00|650.00|700.00|750.00|800.00|850.00|900.00|950.00|1000.00|1500.00|2000.00|2500.00|3000.00|3500.00|4000.00|4500.00|5000.00|5500.00|6000.00|6500.00|7000.00|7500.00|8000.00|8500.00|9000.00|9500.00|10000.00', ...
         'Tag','LambdaDeterPopup');

      d_str = get(deterprior_controls.lambda_d,'String');
      for i=1:size(d_str,1);
         if tm.lambda_d==mystr2num(strtrim(d_str(i,:)));
            set(deterprior_controls.lambda_d,'Value',i);
            break;
         end;
      end;

      %
      % Buttons
      %

      deterprior_controls.helpbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[16 20 20 20], ...
         'String','?', ...
         'TooltipString','Open the help file', ...
         'FontWeight','bold', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'ForegroundColor',[0.5 0 0], ...
         'Enable','on', ...
         'Callback','help_fcn(''PriorDistributions'');', ...
         'Tag','HelpButton');

      deterprior_controls.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-295 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','deterprior_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      deterprior_controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-200 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','deterprior_dlg cancel', ...
         'Enable','on', ...
         'Tag','Cancel');

      deterprior_controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-105 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','deterprior_dlg apply', ...
         'UserData',tm, ...
         'Enable','off', ...
         'Tag','Apply');

      set(deterprior_gui,'UserData',deterprior_controls,...
         'HandleVisibility','callback');

   case 'deterministic'
      d_val = get(deterprior_controls.lambda_d,'Value');
      d_str = get(deterprior_controls.lambda_d,'String');
      newlambda_d = mystr2num(strtrim(d_str(d_val,:)));
      if abs(newlambda_d-tm.lambda_d)>0;
         tm.lambda_d = newlambda_d;
         set(deterprior_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'cancel'
      tm.lambda_d = tm.old.lambda_d;
      curr_ini.lambda_d = tm.lambda_d;
      tm.ini = curr_ini;
      set(deterprior_controls.apply,'Enable','off','UserData',tm);
      %
      % Now we fix the control
      %
      d_str = get(deterprior_controls.lambda_d,'String');
      for i=1:size(d_str,1);
         if tm.lambda_d==mystr2num(strtrim(d_str(i,:)));
            set(deterprior_controls.lambda_d,'Value',i);
            break;
         end;
      end;
   case 'apply'
      curr_ini.lambda_d = tm.lambda_d;
      tm.ini = curr_ini;
      set(deterprior_controls.apply,'Enable','off','UserData',tm);
   case 'done'
      set(deterprior_controls.done,'UserData','done');
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(deterprior_gui,'Name') ' ' fix_filepath([pwd '\icons\lambda_params.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(deterprior_controls.icon,'UserData',pid);
      end;
   end;
   %
   set(deterprior_gui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(deterprior_gui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(deterprior_controls.done);
   end;
   waitfor(deterprior_controls.done,'UserData','done');
end;

if nargout==1;
   h = deterprior_gui;
end;

%
% end of deterprior_dlg.m
%
