function [f,g] = fiml_max_fcn(phi,tm,type_var,Z0,Z1,Z2,beta,r,Nn,Rmat_alpha,rvec_alpha,Rmat_lr,rvec_lr,Rmat_sr,rvec_sr)

%
% where f is the function value and g is the gradient
%

[n T] = size(Z0);

Theta = vecinv(phi,n);

if isempty(Z2)==0;
   Psi = Theta(:,1:size(Z2,1));
   if r>0;
      alpha = Theta(:,size(Theta,2)-(n+r)+1:size(Theta,2)-n);
   else;
      alpha = [];
   end;
else;
   alpha = Theta(:,1:r);
   Psi = [];
end;
B = Theta(:,size(Theta,2)-n+1:size(Theta,2));

%
% create restricted residuals
%

if (isempty(Z2)==0)&(r>0);
  epsilon = Z0-(Psi*Z2)-(alpha*beta'*Z1);
elseif (isempty(Z2)==0)&(r==0);
  epsilon = Z0-(Psi*Z2);
elseif (isempty(Z2)==1)&(r>0);
  epsilon = Z0-(alpha*beta'*Z1);
else;
  epsilon = Z0;
end;

%f = -loglike_fcn(B,epsilon);

Omega = B*B';
if rank(Omega)<n;
   Omega = (1/T)*epsilon*epsilon';
end;
Omega_inv = Omega\eye(n);

f = (T/2)*(n*log(2*pi)+log(det(Omega)))+((1/2)*sum(diag(Omega_inv*epsilon*epsilon')));

if nargout>1;
   %
   % computing the gradient of the objective function
   %
   Z = [];
   if r>0;
      Z = beta'*Z1;
   end;
   Z = [Z2;Z];
   k = size(Z,1);
   g1 = vec(epsilon*Z')'*kron(eye(k),Omega_inv);
   diff_Omega = (Omega_inv*epsilon*epsilon')-(T*eye(n));
   g2 = vec(eye(n))'*kron(diff_Omega,Omega_inv)*Nn*kron(B,eye(n));
   g = -[g1 g2]';
end;

%
% end of fiml_max_fcn.m
%
