%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of data       %
%                                                                %
%          Function: fittedterms                                 %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_mod: structure with model info         %
%                       mytheta: short run parameters            %
%                       mybeta: cointegration matrix             %
%                                                                %
%          Output:                                               %
%          	            h: handle                                %
%                                                                %
%          This version:        May 3, 2006                      %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = fittedterms(selector,c_mod,mytheta,mybeta)

if strcmp(selector,'init')==1;
   t_m = c_mod;
   %
   thisexit = 0;
   curr_ini = find_inisettings;
   %
   t_m.beta = mybeta;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if curr_ini.colors==1;
      t_m.colorstr = 'b';
      t_m.colorstr2 = 'r';
      t_m.typestr = '-';
   else;
      t_m.colorstr = 'k';
      t_m.colorstr2 = [0.5 0.5 0.5];
      t_m.typestr = '--';
   end;
   %
   % setting up the actual sample period
   %
   [t_m.dataindex,t_m.samplebeg,t_m.sampleend] = make_dataindex(t_m.freq,t_m.samplebeg,t_m.sampleend);
   checkyear = floor(t_m.samplebeg);
   checkperiod = t_m.samplebeg-checkyear;
   t_m.subbeginyear = num2str(checkyear);
   if strcmp(t_m.freq,'q')==1;
      checkperiod = 4*(checkperiod+(1/8));
      t_m.subbeginperiod = num2str(round(checkperiod));
   elseif strcmp(t_m.freq,'m')==1;
      checkperiod = 12*(checkperiod+(1/24));
      t_m.subbeginperiod = num2str(round(checkperiod));
   end;
   %
   % preliminaries
   %
   t_m.namevector = vecstr(t_m.evars);
   %
   if t_m.d>0;
      t_m.Z2_deter = t_m.Z2(1:t_m.d,:);
      t_m.Z0_corr = t_m.Z0-((t_m.Z0*t_m.Z2_deter'/(t_m.Z2_deter*t_m.Z2_deter'))*t_m.Z2_deter);
   else;
      t_m.Z2_deter = [];
      t_m.Z0_corr = t_m.Z0;
   end;
   %
   if t_m.p>1;
      Gamma_endo = mytheta(:,t_m.d+1:t_m.n*(t_m.p-1)+t_m.d);
      t_m.Z2_endo = t_m.Z2(t_m.d+1:t_m.n*(t_m.p-1)+t_m.d,:);
   else;
      Gamma_endo = [];
      t_m.Z2_endo = [];
   end;
   n2 = size(mytheta,2);
   myalpha = mytheta(:,n2-t_m.r+1:n2);
   t_m.diff_vars = [];
   if t_m.p>1;
      for j=1:t_m.n;
         for i=1:t_m.n;
            diff_varsi = 0;
            for k=1:t_m.p-1;
               i1 = i+(k-1)*t_m.n;
               diff_varsi = diff_varsi+(Gamma_endo(j,i1)*t_m.Z2_endo(i1,:));
            end;
            t_m.diff_vars = [t_m.diff_vars;diff_varsi];
         end;
      end;
   end;
   %
   if t_m.d>0;
      t_m.diff_vars = t_m.diff_vars-((t_m.diff_vars*t_m.Z2_deter'/(t_m.Z2_deter*t_m.Z2_deter'))*t_m.Z2_deter);
   end;
   %
   if t_m.r>0;
      coint_rel = t_m.beta'*t_m.Z1;
      t_m.coint_vars = [];
      for j=1:t_m.n;
         for i=1:t_m.r;
            t_m.coint_vars = [t_m.coint_vars;myalpha(j,i)*coint_rel(i,:)];
         end;
      end;
      if t_m.d>0;
         t_m.coint_vars = t_m.coint_vars-((t_m.coint_vars*t_m.Z2_deter'/(t_m.Z2_deter*t_m.Z2_deter'))*t_m.Z2_deter);
      end;
   end;
   t_m.realscrsz = get(0,'ScreenSize');
else;
   thisexit = 1;
   fittedgui = get(0,'CurrentFigure');
   fitted = get(fittedgui,'UserData');
   curr_ini = get(fitted.popup,'UserData');
   t_m = curr_ini.models;
end;

switch selector;
   case 'init';
      fittedgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','fittedterms.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(t_m.realscrsz(3)-341)/2 (t_m.realscrsz(4)-140)/2 341 140], ...
         'Tag','FigParent', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Graph Fitted Terms', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','fittedterms done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(fittedgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 130],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 80 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.fittedterms_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      fitted.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 50 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',['Estimation Sample:  ' t_m.subbeginyear ':' t_m.subbeginperiod ' - ' t_m.subendyear ':' t_m.subendperiod], ...
         'HorizontalAlignment','left', ...
         'Tag','SampleText');

      %
      % Select variable
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 80 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Select Variable:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');


      fitted.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[120 20 80 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',t_m.namevector, ...
         'HorizontalAlignment','center', ...
         'Tag','GraphListbox',...
         'Value',1);

      %
      % Create graph button
      %

      fitted.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','fittedterms showgraph', ...
         'Enable','on', ...
         'UserData','working', ...
         'Tag','Done');

      %
      %  Done button
      %

      fitted.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','fittedterms done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(fittedgui,'UserData',fitted,...
         'HandleVisibility','callback');

   case 'showgraph'
      series = get(fitted.popup,'Value');
      newvalue = series+1;
      if newvalue>t_m.n;
         set(fitted.popup,'Value',1);
      else;
         set(fitted.popup,'Value',newvalue);
      end;
      %
      % setting up the graphs
      %
      num_cols = floor(sqrt(t_m.n));
      num_rows = ceil(t_m.n/num_cols);
      if num_cols*num_rows<t_m.n;
         num_rows = num_rows+1;
      end;
      width = min(num_cols*500,t_m.realscrsz(3));
      height = min((t_m.realscrsz(4)/t_m.realscrsz(3))*(num_rows*300),t_m.realscrsz(4));
      %
      % first difference terms
      %
      file_names = '';
      stats = [];
      %
      thispos = [(t_m.realscrsz(3)-width)/2-22 (t_m.realscrsz(4)-height)/2+22];
      %
      if t_m.p>1;
         diff_series = t_m.diff_vars(1+((series-1)*t_m.n):series*t_m.n,:);
         endo_series = t_m.Z0_corr(series,:);
         %
         % fixing the position
         %
         thispos = [thispos(1,1)+22 thispos(1,2)-22];
         if thispos(1,1)>(t_m.realscrsz(3)-width);
            thispos = [0 t_m.realscrsz(4)-height];
         end;
         if thispos(1,2)>(t_m.realscrsz(4)-height);
            thispos = [0 t_m.realscrsz(4)-height];
         elseif thispos(1,2)<32;
            thispos = [0 t_m.realscrsz(4)-height];
         end;
         myplot = figure('Units','pixels', ...
            'Position',[thispos width height], ...
            'Menubar','none', ...
            'Toolbar','none', ...
            'NumberTitle','off', ...
            'Visible','off', ...
            'Name',[strtrim(t_m.namevector(series,:)) ' and fitted lagged first difference terms']);
         %
         % obey centering and filling defaults
         %
         setfigureproperties(myplot);
         %
         %
         % Setting up the sub plots
         %
         axeshandles = [];
         for i=1:t_m.n;
            subplot(num_rows,num_cols,i);
            line_one = plot(t_m.dataindex,endo_series','-','LineWidth',1,'Color',t_m.colorstr,'Tag',['d' strtrim(t_m.namevector(series,:))]);
            hold('on');
            line_two = plot(t_m.dataindex,diff_series(i,:)',t_m.typestr,'LineWidth',1,'Color',t_m.colorstr2,'Tag',['fitted-d' strtrim(t_m.namevector(series,:)) '-' strtrim(t_m.namevector(i,:))]);
            hold('on');
            plot(t_m.dataindex,zeros(t_m.T,1),'-','LineWidth',1,'Color','k');
            set(gca,'XLim',[t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)]);
            set(gca,'YLim',1.05*[min(min(endo_series),min(diff_series(i,:))) max(max(endo_series),max(diff_series(i,:)))]);
            setaxesfonts('Title',['\Delta' strtrim(t_m.namevector(series,:)) ' and fitted terms for lagged \Delta' strtrim(t_m.namevector(i,:))]);
            myleg = legend_fcn([line_one line_two],['\Delta ' strtrim(t_m.namevector(series,:))],['Lagged \Delta' strtrim(t_m.namevector(i,:))],2);
            setaxesfonts(myleg);
            set(gca,'UserData',myleg);
            axeshandles = [axeshandles gca];
            hold('off');
         end;
         toolbar_fcn(axeshandles);
         %
         % take care of automatically saving the graphs
         %
         if curr_ini.external==0;
            set(myplot,'Visible','on');
            drawnow;
            drawnow;
         else;
            file = [t_m.outputdir 'diff-' strtrim(t_m.namevector(series,:)) '-lagged-diffs-fitted-terms'];
            mstat = autosavefigure(myplot,file);
            stats = [stats mstat];
            file_names = strvcat(file_names,file);
         end;
      end;
      %
      if t_m.r>0;
         n_cols = floor(sqrt(t_m.r));
         n_rows = ceil(t_m.r/n_cols);
         if n_cols*n_rows<t_m.r;
            n_rows = n_rows+1;
         end;
         c_width = min(n_cols*500,t_m.realscrsz(3));
         c_height = min((t_m.realscrsz(4)/t_m.realscrsz(3))*(n_rows*300),t_m.realscrsz(4));
         %
         % cointegration relations
         %
         last_pos = get(gcf,'Position');
         thispos = last_pos(1:2)+[0 height-c_height];
         %
         coint_series = t_m.coint_vars(1+((series-1)*t_m.r):series*t_m.r,:);
         endo_series = t_m.Z0_corr(series,:);
         thispos = [thispos(1,1)+22 thispos(1,2)-22];
         if thispos(1,1)>(t_m.realscrsz(3)-c_width);
            thispos = [0 t_m.realscrsz(4)-c_height];
         end;
         if thispos(1,2)>(t_m.realscrsz(4)-c_height);
            thispos = [0 t_m.realscrsz(4)-c_height];
         elseif thispos(1,2)<32;
            thispos = [0 t_m.realscrsz(4)-c_height];
         end;
         myplot = figure('Units','pixels', ...
            'Position',[thispos c_width c_height], ...
            'Menubar','none', ...
            'Toolbar','none', ...
            'NumberTitle','off', ...
            'Visible','off', ...
            'Name',[strtrim(t_m.namevector(series,:)) ' and fitted lagged cointegration relations']);
         %
         % obey centering and filling defaults
         %
         setfigureproperties(myplot);
         %
         %
         % Setting up the sub plots
         %
         axeshandles = [];
         for i=1:t_m.r;
            subplot(n_rows,n_cols,i);
            line_one = plot(t_m.dataindex,endo_series','-','LineWidth',1,'Color',t_m.colorstr,'Tag',['d' strtrim(t_m.namevector(series,:))]);
            hold('on');
            line_two = plot(t_m.dataindex,coint_series(i,:)',t_m.typestr,'LineWidth',1,'Color',t_m.colorstr2,'Tag',['fitted-d' strtrim(t_m.namevector(series,:)) '-coint(' num2str(i) ')']);
            hold('on');
            plot(t_m.dataindex,zeros(t_m.T,1),'-','LineWidth',1,'Color','k');
            set(gca,'XLim',[t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)]);
            set(gca,'YLim',1.05*[min(min(endo_series),min(coint_series(i,:))) max(max(endo_series),max(coint_series(i,:)))]);
            setaxesfonts('Title',['\Delta' strtrim(t_m.namevector(series,:)) ' and fitted terms for cointegration relation ' num2str(i)]);
            if t_m.r==1;
               old_ax_units = get(gca,'Units');
               set(gca,'Units','pixels');
               set(gca,'Position',get(gca,'Position')-[0 0 0 10]);
               set(gca,'Units',old_ax_units);
            end;
            myleg = legend_fcn([line_one line_two],['\Delta ' strtrim(t_m.namevector(series,:))],['Coint. rel. no. ' num2str(i)],2);
            setaxesfonts(myleg);
            set(gca,'UserData',myleg);
            axeshandles = [axeshandles gca];
            hold('off');
         end;
         toolbar_fcn(axeshandles);
         %
         % take care of automatically saving the graphs
         %
         if curr_ini.external==0;
            set(myplot,'Visible','on');
            drawnow;
            drawnow;
         else;
            useres = '';
            file = [t_m.outputdir 'diff-' strtrim(t_m.namevector(series,:)) '-coint-relations-fitted-terms'];
            mstat = autosavefigure(myplot,file);
            stats = [stats mstat];
            file_names = strvcat(file_names,file);
         end;
      end;
      %
      if curr_ini.external==1;
         if isempty(stats)==0;
            for i=1:size(stats,2);
               if stats(i)==0;
                  autoshowfigure(strtrim(file_names(i,:)));
               end;
            end;
         end;
      end;
   case 'done'
      set(fitted.done,'UserData','done');
end;

if nargout==1;
   h = fittedgui;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = t_m;
   set(fitted.popup,'UserData',curr_ini);
   set(fittedgui,'UserData',fitted);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(fittedgui,'Name') ' ' fix_filepath([pwd '\icons\fittedterms.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(fitted.icon,'UserData',pid);
      end;
   end;
   %
   set(fittedgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(fittedgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(fitted.done);
   end;
   waitfor(fitted.done,'UserData','done');
end;

%
% end of fittedterms.m
%
