%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for getting time period as a string   %
%                                                                %
%          Function: getdate                                     %
%                                                                %
%          Input:                                                %
%                       samplebeg: first period (real)           %
%                       sampleend: last period (real)            %
%                       freq: data frequence string (y,q,m)      %
%                       thisdate: relative time period to end    %
%                          (where end = 1)                       %
%                                                                %
%          Output:                                               %
%                       date: text string                        %
%                                                                %
%          This version:        October 25, 2003                 %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2003          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function date = getdate(samplebeg,sampleend,freq,thisdate)

%
% setting up the actual sample period
%

if strcmp(freq,'q')==1;
   nsamplebeg = samplebeg-(1/8);
   nsampleend = sampleend-(1/8);
   add = 1/4;
elseif strcmp(freq,'m')==1;
   nsamplebeg = samplebeg-(1/24);
   nsampleend = sampleend-(1/24);
   add = 1/12;
else;
   nsamplebeg = samplebeg;
   nsampleend = sampleend;
   add = 1;
end;
dataindex = nsamplebeg;
lastentry = dataindex;
j = 2;
while lastentry<=nsampleend;
   lastentry = dataindex(j-1,1)+add;
   if lastentry<=nsampleend;
      dataindex = [dataindex;lastentry];
      j = j+1;
   else;
      break;
   end;
end;

t = round(thisdate*size(dataindex,1));

datevalue = dataindex(t,1);

date = num2str(floor(datevalue),'%1.0f');

if strcmp(freq,'q')==1;
   datevalue = (datevalue-floor(datevalue)+(1/8))*4;
   date = [date ':' num2str(datevalue,'%1.0f')];
elseif strcmp(freq,'m')==1;
   datevalue = (datevalue-floor(datevalue)+(1/24))*12;
   if datevalue>12;
      datevalue = datevalue-12;
      date_new = dataindex(t,1);
      date = num2str(date_new,'%0.0f');
   end;
   date = [date ':' num2str(ceil(datevalue),'%1.0f')];
else;
   date = [date ':1'];
end;

%
% end of getdate.m
%
