function posterior_data = getposteriordata(controls,cm)

%
% loads posteriors draws from mat-files and presents into a structure containing the fields
%
%   beta
%   alpha
%   delta
%   Gamma
%   Psi
%   Omega
%   epsilon
%   max_evalue
%

%
% Loading data
%

mywait = waitdlg(strvcat(' ','Loading data series.','Please wait!'),'information','Posterior Draws',350,124);
waitf = get(mywait,'UserData');

%
% read data from file
%
if get(controls.betarest,'Value')==1;
   %
   % get file from beta estimation
   %
   file = get(controls.results_beta,'UserData');
   posterior_data = [];
   if strcmp(file,'')==0;
      file = strrep(file,'.txt','.mat');
      if fileexist(file)==1;
         f = load(file);
         if isfield(f,'betafilename')==1;
            file = f.betafilename;
            if fileexist(file)==1;
               f = load(file);
               posterior_data = f.gibbs_results.posterior;
            end;
         end;
         clear('f');
      end;
   end;
else;
   %
   % get file from cointegration rank estimation
   %
   file = get(controls.results_rank,'UserData');
   posterior_data = [];
   if strcmp(file,'')==0;
      file = strrep(file,'.txt','.mat');
      file = strrep(file,['rank-gibbs-' num2str(cm.scale_endo,'%0.4f')],['rank-' num2str(cm.r,'%0.0f') '-' num2str(cm.scale_endo,'%0.4f') '-gibbs']);
      if fileexist(file)==1;
         f = load(file);
         if isfield(f,'rankfilenames')==1;
            file = strtrim(f.rankfilenames(cm.r+1,:));
            if fileexist(file)==1;
               f = load(file);
               posterior_data = f.gibbs_results.posterior;
            end;
         end;
         clear('f');
      end;
   end;
end;

%
% Close the wait dialog
%

set(waitf.text,'UserData','done');
delete(mywait);
drawnow;

%
% end of getposteriordata.m
%
