%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the LR/F test     %
%          for restrictions on A and B and estimate confidence   %
%          intervals for the free A and B parameters and         %
%          impulse responses                                     %
%                                                                %
%          Function: ir_bootstrap                                %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 10, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function ir_bootstrap(varargin)

%
% GUI for bootstrapping the A, B and impulse responses distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   if tm.restrict(1,1)==1;
      tm.resalpha = 'alpha-';
   else;
      tm.resalpha = '';
   end;
   if tm.restrict(1,2)==1;
      tm.resbeta = 'beta-';
   else;
      tm.resbeta = '';
   end;
   if tm.restrict(1,3)==1;
      tm.resc = 'c-';
   else;
      tm.resc = '';
   end;
   tm.file_df = [num2str(tm.structural_df,'%0.0f') '-' num2str(tm.p,'%0.0f') '.' num2str(tm.q1,'%0.0f') '.' num2str(tm.q0,'%0.0f') '-'];
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.ir_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if strcmp(computer,'PCWIN')==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if curr_ini.sscorrect==1;
      tm.testtype = '-f';
   else;
      tm.testtype = '-lr';
   end;
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      ir_mat = load(full_mat);
      if tm.structural_df>0;
         ir_test_sorted = ir_mat.ir_test_sorted;
      else;
         ir_test_sorted = [];
      end;
      a_vec = ir_mat.a_vec;
      a_t_dist = ir_mat.a_t_dist;
      b_vec = ir_mat.b_vec;
      b_t_dist = ir_mat.b_t_dist;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      ir_test_sorted = [];
      a_vec = [];
      a_t_dist = [];
      b_vec = [];
      b_t_dist = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if impulse responses have been saved to disk
   %
   num_ir = 0;
   for i=1:tm.n;
      for j=1:tm.n;
         if tm.const_model(1)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         if fileexist(new_file)==1;
            num_ir = num_ir+1;
         else;
            break;
         end;
      end;
   end;
   %
   if num_ir==tm.n*tm.n;
      ir_enable = 'on';
   else;
      ir_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'ir-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'ir-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      boot_enable = 'off';
   end;
   if fileexist(testfile)==0;
      testfile = '';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   ir_boot_gui = findobj('Type','figure','Tag','IRBoot')';
   boot_ir = get(ir_boot_gui,'UserData');
   curr_ini = get(boot_ir.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   ir_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','ir_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-465)/2 560 465], ...
         'Tag','IRBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Structural Parameters', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','ir_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(ir_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',ir_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_ir.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','ir_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_ir.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','ir_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_ir.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','ir_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_ir.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','ir_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_ir.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','ir_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_ir.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','ir_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_ir.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',ir_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_ir.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','ir_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_ir.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','ir_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_ir.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','ir_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   boot_ir.ir_displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Impulse Responses', ...
         'Callback','ir_bootstrap ir_display', ...
         'Separator','on', ...
         'Accelerator','I', ...
         'UserData',[], ...
         'Enable',ir_enable, ...
         'Tag','IRDisplayMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',ir_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_ir.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_ir.toolbar = uitoolbar('Parent',ir_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 464 560],[0.5 1]);
   end;

   boot_ir.simulate = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','ir_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_ir.matfilebutton = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','ir_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_ir.summary = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','ir_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData',b_t_dist, ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_ir.full = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','ir_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',a_t_dist, ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_ir.bootstrapgraph = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','ir_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_ir.display = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','ir_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',ir_test_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_ir.histogram = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','ir_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',a_vec, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_ir.ir_display = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Impulse Responses', ...
                      'CData',button_images.irfunction, ...
                      'ClickedCallback','ir_bootstrap ir_display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',ir_test_sorted, ...
                      'Clipping','on', ...
                      'Enable',ir_enable, ...
                      'Tag','ViewIRButton');

   boot_ir.help = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_ir.done = uipushtool('Parent',boot_ir.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','ir_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 450],'Structural Parameters',105,[0.5 1]);

   %
   % GUI Header
   %

   if curr_ini.sscorrect==1;
      header_txt = ['Bootstrap A, B, Impulse Responses, and F Test (' model_type ' Model)'];
   else;
      header_txt = ['Bootstrap A, B, Impulse Responses, and LR Test (' model_type ' Model)'];
   end;
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 366 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 190 155 160],'Options',35,[0.5 1]);

   boot_ir.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 315 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',b_vec, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_ir.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 295 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_ir.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 275 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_ir.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 255 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','ir_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');

   boot_ir.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 225 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_ir.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 230 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','ir_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_ir.blocktext,'Enable','on');
      set(boot_ir.block,'Enable','on');
   end;

   boot_ir.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 205 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 190 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_ir.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 309 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_ir.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 314 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','ir_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_ir.obstext,'Enable','on');
      set(boot_ir.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 256.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_ir.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 261.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','ir_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % Trim parameter estimates
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 204 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Trim tails of parameter dist. by:', ...
      'Tag','TrimText');

   boot_ir.trim_estimates = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 209 168 20], ...
      'Value',1, ...
      'String','0%|0.05%|0.1%|0.2%|0.3%|0.4%|0.5%|0.6%|0.7%|0.8%|0.9%|1%|2%|3%|4%|5%', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TrimmingPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 160],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 134 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_ir.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 139 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','ir_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Select bootstrap distribution for parameter graphs
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 99 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Parameter distribution:', ...
      'Tag','BootDistText');

   boot_ir.bootdist = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 104 168 20], ...
      'Value',1, ...
      'String','bootstrapped t-statistic|bootstrapped parameters', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BootDistPopup');
   
   %
   % graph functions
   %
   
   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 64 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Graph distributions for:', ...
      'Tag','GraphTypeText');
   
   if isempty(tm.LR_B0)==0;
      grt_str = 'LR-test|LR-test & A matrix|LR-test & B matrix|LR-test, A & B matrices|A matrix|A & B matrices|B matrix';
      tm.a_num = [2 4 5 6];
      tm.b_num = [3 4 6 7];
      tm.lr_num = [1 2 3 4];
   else;
      grt_str = 'A matrix|A & B matrices|B matrix';
      tm.a_num = [1 2];
      tm.b_num = [2 3];
      tm.lr_num = [];
   end;
   
   boot_ir.graphtype = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 69 168 20], ...
      'Value',1, ...
      'String',grt_str, ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','GraphTypePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_ir.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   %
   % Additional options
   %

   boot_ir.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 140 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_ir.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 103+(1/3) 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_ir.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 66+(2/3) 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_ir.pq_plot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 30 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQplotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_ir.adaptive,'Enable','on');
   end;

   if tm.structural_df==0;
      set(boot_ir.bart,'Enable','off');
      set(boot_ir.pq_plot,'Enable','off');
   end;

   set(ir_boot_gui,'UserData',boot_ir,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_ir.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Impulse Responses} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_ir.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Impulse Reponses\n                      ----------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_ir.bootstrapgraph,'UserData');
   testfile = get(boot_ir.bootstrapgraphmenu,'UserData');
   my_T = get(boot_ir.obs,'UserData');
   rep = get(boot_ir.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      if tm.structural_df>0;
         if curr_ini.sscorrect==1;
            txt_str = ['F(' num2str(tm.structural_df,'%0.0f') ',' num2str(my_T-tm.df,'%0.0f') ') ='];
         else;
            txt_str = ['LR(' num2str(tm.structural_df,'%0.0f') ') ='];
         end;
      else;
         txt_str = '';
      end;
      %
      set(ir_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta,rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(ir_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_ir.parametric,'Value')==0;
      T_str = get(boot_ir.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_ir.obs,'Value'),:)));
      set(boot_ir.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_ir.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_ir.obs,'Enable','on');
      set(boot_ir.obstext,'Enable','on');
   end;
   ir_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_ir.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_ir.adaptive,'Enable','on');
   else;
      set(boot_ir.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   ir_test_sorted = get(boot_ir.display,'UserData');
   a_vec = get(boot_ir.histogram,'UserData');
   a_t_dist = get(boot_ir.full,'UserData');
   b_vec = get(boot_ir.clock,'UserData');
   b_t_dist = get(boot_ir.summary,'UserData');
   rep = get(boot_ir.rep,'UserData');
   my_T = get(boot_ir.obs,'UserData');
   my_const_model = get(boot_ir.displaymenu,'UserData');
   if get(boot_ir.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_ir.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      if tm.structural_df>0;
         save(full_mat,'ir_test_sorted','a_vec','a_t_dist','b_vec','b_t_dist');
      else;
         save(full_mat,'a_vec','a_t_dist','b_vec','b_t_dist');
      end;
   end;
case 'check'
   T_str = get(boot_ir.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_ir.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_ir.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_ir.rep,'UserData',rep);
   set(boot_ir.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_ir.parametric,'Value')==1;
      bootstyle = '';
      set(boot_ir.blocktext,'Enable','off');
      set(boot_ir.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_ir.block,'Enable'),'off')==1;
         set(boot_ir.blocktext,'Enable','on');
         set(boot_ir.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_ir.block,'Value')) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      ir_mat = load(full_mat);
      if tm.structural_df>0;
         ir_test_sorted = ir_mat.ir_test_sorted;
      else;
         ir_test_sorted = [];
      end;
      a_vec = ir_mat.a_vec;
      a_t_dist = ir_mat.a_t_dist;
      b_vec = ir_mat.b_vec;
      b_t_dist = ir_mat.b_t_dist;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_ir.display,'Enable','on','UserData',ir_test_sorted);
      set(boot_ir.histogram,'Enable','on','UserData',a_vec);
      set(boot_ir.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_ir.full,'UserData',a_t_dist);
      set(boot_ir.clock,'UserData',b_vec);
      set(boot_ir.summary,'UserData',b_t_dist);
      set(boot_ir.histogrammenu,'Enable','on');
      set(boot_ir.matfilebutton,'Enable','on');
      set(boot_ir.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_ir.display,'Enable','off','UserData',[]);
      set(boot_ir.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_ir.histogram,'Enable','off','UserData',[]);
      set(boot_ir.full,'UserData',[]);
      set(boot_ir.clock,'UserData',[]);
      set(boot_ir.summary,'UserData',[]);
      set(boot_ir.histogrammenu,'Enable','off');
      set(boot_ir.matfilebutton,'Enable','off');
      set(boot_ir.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'ir-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'ir-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_ir.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_ir.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   elseif fileexist(testfile)==1;
      set(boot_ir.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_ir.bootstrapgraphmenu,'Enable','off','UserData',testfile);
   else;
      set(boot_ir.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_ir.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_ir.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_ir.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_ir.output,'Enable',summary_enable);
   end;
   set(boot_ir.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_ir.summary,'Enable',summary_enable);
   %
   % check if impulse responses have been saved to disk
   %
   num_ir = 0;
   for i=1:tm.n;
      for j=1:tm.n;
         if tm.const_model(1)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         if fileexist(new_file)==1;
            num_ir = num_ir+1;
         else;
            break;
         end;
      end;
   end;
   %
   if num_ir==tm.n*tm.n;
      set(boot_ir.ir_display,'Enable','on');
      set(boot_ir.ir_displaymenu,'Enable','on');
   else;
      set(boot_ir.ir_display,'Enable','off');
      set(boot_ir.ir_displaymenu,'Enable','off');
   end;
   set(ir_boot_gui,'UserData',boot_ir);
case 'summary'
   set(ir_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_ir.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Impulse Response Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(ir_boot_gui,'Visible','on');
   drawnow;
   set(ir_boot_gui,'UserData',boot_ir);
case 'full'
   set(ir_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_ir.rep,'UserData');
   full_mat = lower(get(boot_ir.fullmenu,'UserData'));
   my_T = get(boot_ir.obs,'UserData');
   %
   % loading data
   %
   ir_test_sorted = get(boot_ir.display,'UserData');
   a_vec = get(boot_ir.histogram,'UserData');
%   a_t_dist = get(boot_ir.full,'UserData');
   b_vec = get(boot_ir.clock,'UserData');
%   b_t_dist = get(boot_ir.summary,'UserData');
   %
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   sp_str = spacestr(curr_ini.decimals-2);
   my_data = (1:1:rep)';
   prt_str = '%7.0f';
   head_str = ' Number';
   if tm.structural_df>0;
      if curr_ini.sscorrect==1;
         head_str = [head_str sp_str sprintf('  F(%2.0f,%3.0f)',tm.structural_df,my_T-tm.df)];
      else;
         head_str = [head_str sp_str sprintf('     LR(%2.0f)',tm.structural_df)];
      end;
      my_data = [my_data ir_test_sorted];
      prt_str = [prt_str '   ' prt_val];
   end;
   for i=1:tm.n;
      for j=1:tm.n;
         elem = j+(tm.n*(i-1));
         if isalmostequal(a_vec(1,elem),a_vec(rep,elem))==0;
            head_str = [head_str sp_str sprintf('   A(%2.0f,%2.0f)',j,i)];
            my_data = [my_data a_vec(:,elem)];
            prt_str = [prt_str '   ' prt_val];
         end;
      end;
   end;
   for i=1:tm.n;
      for j=1:tm.n;
         elem = j+(tm.n*(i-1));
         if isalmostequal(b_vec(1,elem),b_vec(rep,elem))==0;
            head_str = [head_str sp_str sprintf('   B(%2.0f,%2.0f)',j,i)];
            my_data = [my_data b_vec(:,elem)];
            prt_str = [prt_str '   ' prt_val];
         end;
      end;
   end;
   %
   % writing to text string
   %
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   %
   add_txt = '';
   for i=1:rep;
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      new_txt = sprintf(prt_str,my_data(i,:)');
      add_txt = strvcat(add_txt,new_txt);
   end;
   %
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   %
   if strcmp(abort,'cancel')==0;
      my_text = strvcat(' ',head_str,' ',add_txt,' ');
      textgui(my_text,'Structural VAR - Structural Model Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(ir_boot_gui,'Visible','on');
   drawnow;
   set(ir_boot_gui,'UserData',boot_ir);
   %
   % case display impulse responses with bootstrapped confidence intervals
   %
case 'ir_display'
   set(ir_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_ir.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_ir.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_ir.rep,'Value');
   rep = repvalues(rep_val);
   if get(boot_ir.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_ir.block,'Value')) '-'];
   end;
   %
   trim_val = get(boot_ir.trim_estimates,'Value');
   if trim_val>1;
      trim_str = get(boot_ir.trim_estimates,'String');
      trim_p = strrep(trim_str(trim_val,:),'%','');
      trim_p = mystr2num(trim_p)/200;
      low_bval = ceil(trim_p*rep)+1;
      high_bval = rep+1-low_bval;
   else;
      low_bval = 1;
      high_bval = rep;
   end;
   %
   % store original values if any
   %
   store_old_val = 0;
   if (isfield(tm,'ir')==1)&(isempty(tm.ir)==0);
      store_old_val = 1;
      tm.old_ir = tm.ir;
      tm.old_betair = tm.betair;
      if isfield(tm,'upper')==1;
         tm.old_upper = tm.upper;
         tm.old_lower = tm.lower;
         tm.old_betair_upper = tm.betair_upper;
         tm.old_betair_lower = tm.betair_lower;
      end;
   end;
   %
   % check which bootstrap distribution to use (1 = t-dist, 2=param dist)
   %
   dist_type = get(boot_ir.bootdist,'Value');
   up_val = (100+tm.c)/200;
   low_val = 1-up_val;
   %
   for i=1:tm.n;
      for j=1:tm.n;
         if tm.const_model(1)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            tm.boot_model_type = 'noconst';
         elseif tm.const_model(2)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            tm.boot_model_type = 'resconst';
         elseif tm.const_model(3)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            tm.boot_model_type = 'const';
         elseif tm.const_model(4)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            tm.boot_model_type = 'restrend';
         elseif tm.const_model(5)==1;
            new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            tm.boot_model_type = 'trend';
         end;
         ir_struc = load(new_file);
         if i*j==1;
            tm.ir = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            tm.upper = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            tm.lower = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            tm.mean_ir = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            tm.median_ir = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            if tm.r>0;
               tm.betair = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
               tm.betair_upper = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
               tm.betair_lower = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
               tm.mean_betair = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
               tm.median_betair = zeros(tm.n*tm.n,size(ir_struc.est_ir,2));
            else;
               tm.betair = [];
            end;
         end;
         elem = i+(tm.n*(j-1));
         tm.ir(elem,:) = ir_struc.est_ir;
         if (isempty(tm.betair)==0)&(i<=tm.r);
            elem_beta = i+(tm.r*(j-1));
            if isfield(ir_struc,'est_betair')==1;
               tm.betair(elem_beta,:) = ir_struc.est_betair;
               tm.mean_betair(elem_beta,:) = (1/(high_bval+1-low_bval))*sum(ir_struc.betair_var_shock(low_bval:high_bval,:));
               tm.median_betair(elem_beta,:) = ir_struc.betair_var_shock(ceil(0.5*rep),:);
               if dist_type==1;
                  tm.betair_upper(elem_beta,:) = ir_struc.est_betair-(sqrt(tm.T/my_T)*( ir_struc.betair_var_shock_t(ceil(low_val*rep),:) .* ir_struc.std_betair));
                  tm.betair_lower(elem_beta,:) = ir_struc.est_betair-(sqrt(tm.T/my_T)*( ir_struc.betair_var_shock_t(ceil(up_val*rep),:) .* ir_struc.std_betair));
               else;
                  tm.betair_upper(elem_beta,:) = ir_struc.betair_var_shock(ceil(up_val*rep),:);
                  tm.betair_lower(elem_beta,:) = ir_struc.betair_var_shock(ceil(low_val*rep),:);
               end;
            else;
               tm.betair = [];
            end;
         end;
         %
         % set the mean and the median
         %
         tm.mean_ir(elem,:) = (1/(high_bval+1-low_bval))*sum(ir_struc.ir_var_shock(low_bval:high_bval,:));
         tm.median_ir(elem,:) = ir_struc.ir_var_shock(ceil(0.5*rep),:);
         %
         % get the upper and lower limits
         %
         if dist_type==1;
            %
            % using t-value distribution. notice that upper limit uses lower t-stat, while lower limit
            %                             uses upper t-stat
            %
            tm.upper(elem,:) = ir_struc.est_ir-(sqrt(tm.T/my_T)*( ir_struc.ir_var_shock_t(ceil(low_val*rep),:) .* ir_struc.std_ir));
            tm.lower(elem,:) = ir_struc.est_ir-(sqrt(tm.T/my_T)*( ir_struc.ir_var_shock_t(ceil(up_val*rep),:) .* ir_struc.std_ir));
         else;
            %
            % using parameter distribution
            %
            tm.upper(elem,:) = ir_struc.ir_var_shock(ceil(up_val*rep),:);
            tm.lower(elem,:) = ir_struc.ir_var_shock(ceil(low_val*rep),:);
         end;
      end;
   end;
   %
   tm.my_T = my_T;
   tm.rep = rep;
   if dist_type==1;
      tm.boot_model_type = ['tdist-' tm.boot_model_type];
      tm.ir_legend_str = ' (t-dist)';
   else;
      tm.boot_model_type = ['parmdist-' tm.boot_model_type];
      tm.ir_legend_str = ' (param dist)';
   end;
   %
   % Open impulse response graphics dialog
   %
   thisgraph = ir_graphdlg('init',tm);
   ir_graph = get(thisgraph,'UserData');
   set(ir_graph.show,'UserData','done');
   killguipid(thisgraph);
   %
   set(ir_boot_gui,'Visible','on');
   drawnow;
   %
   % reset original values if any
   %
   if store_old_val==1;
      tm.ir = tm.old_ir;
      tm.betair = tm.old_betair;
      if isfield(tm,'old_upper')==1;
         tm.upper = tm.old_upper;
         tm.lower = tm.old_lower;
         tm.betair_upper = tm.old_betair_upper;
         tm.betair_lower = tm.old_betair_lower;
      end;
   else;
      tm = rmfield(tm,{'ir' 'upper' 'lower'});
   end;
   %
   % case display distributions of test, A and B parameters
   %
case 'display'
   rep = get(boot_ir.rep,'UserData');
   my_T = get(boot_ir.obs,'UserData');
   %
   % loading data
   %
   ir_test_sorted = get(boot_ir.display,'UserData');
   a_vec = get(boot_ir.histogram,'UserData');
   a_t_dist = get(boot_ir.full,'UserData');
   b_vec = get(boot_ir.clock,'UserData');
   b_t_dist = get(boot_ir.summary,'UserData');
   %
   % determine the type of parameter distribution to use
   % (1 = t-value, 2 = parameter)
   %
   dist_type = get(boot_ir.bootdist,'Value');
   %
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   %
   % trim A and B
   %
   trim_val = get(boot_ir.trim_estimates,'Value');
   if trim_val>1;
      trim_str = get(boot_ir.trim_estimates,'String');
      trim_p = strrep(trim_str(trim_val,:),'%','');
      trim_p = mystr2num(trim_p)/200;
      b_val = ceil(trim_p*rep)+1;
      t_val = rep+1-b_val;
   else;
      b_val = 1;
      t_val = rep;
   end;
   %
   %
   % need to fix the rest
   %
   cell_value = get(boot_ir.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   cdf_value = get(boot_ir.cdf,'Value');
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
      col.vec_9 = (1/255)*[255 255 177];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
      col.vec_9 = col.vec_3;
   end;
   %
   if (tm.structural_df>0)&(isempty(tm.lr_num(tm.lr_num==get(boot_ir.graphtype,'Value')))==0);
      df = tm.df;
      ir_series = [];
      %
      if (gcbo==boot_ir.display)|(gcbo==boot_ir.displaymenu);
         if curr_ini.sscorrect==1;
            df = [tm.structural_df (my_T-tm.df)];
         else;
            df = tm.structural_df;
         end;
         [ir_series,ir_quant,ir_table] = asymp_series(df,curr_ini.sscorrect);
         if get(boot_ir.pq_plot,'Value')==1;
            [p_series,pp_series,qq_series] = pq_plot_series(ir_test_sorted,ir_quant,ir_table,df,curr_ini.sscorrect);
         end;
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(tm.structural_df,'%0.0f') ',' num2str(my_T-tm.df,'%0.0f') ')'];
      else;
         add_name = ['LR(' num2str(tm.structural_df,'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_ir.display)|(gcbo==boot_ir.displaymenu))&(get(boot_ir.pq_plot,'Value')==1);
         [pos,newplot] = pq_plot(pos,'struc-test-pqplot-',['P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,ir_quant,ir_table,p_series,pp_series,qq_series,col);
      end;
      [pos,thisplot] = dist_plot(pos,'struc-test-plot-',['Density for ' add_name ' Test'],[add_name ' test of structural model'],tm,curr_ini,boot_ir,ir_test_sorted,ir_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,df);
      clear('ir_test_sorted','ir_series');
   end;
   %
   param_plot = [];
   t_series = [];
   %
   % check if we should plot A parameters
   %
   if isempty(tm.a_num(tm.a_num==get(boot_ir.graphtype,'Value')))==0;
      if dist_type==2;
         num_row = 1;
         num_col = 1;
         for i=1:size(a_vec,2);
            if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
               %
               % plotting empirical distrbutions for A
               %
               [pos,bplot] = parm_dist(pos,['a-' num2str(num_col,'%0.0f') '.' num2str(num_row,'%0.0f') '-plot-'],['Density for A(' num2str(num_col,'%0.0f') ',' num2str(num_row,'%0.0f') ') parameter (bootstrapped A)'],['Bootstrapped A_{' num2str(num_col,'%0.0f') num2str(num_row,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped A distribution'],tm.A(num_col,num_row),tm.A(num_col,num_row),tm.std_A(num_col,num_row),tm,curr_ini,boot_ir,my_T,[],a_vec(b_val:t_val,i),1,numcells,col,rep);
               param_plot = [param_plot bplot];
            end;
            if num_col==tm.n;
               num_col = 1;
               num_row = num_row+1;
            else;
               num_col = num_col+1;
            end;
         end;
      else;
         %
         % 2D plots based on t-values
         %
         if isempty(a_t_dist)==0;
            %
            % construct the asymptotic distribution for A based on t-value
            %
            if (size(a_t_dist,2)>0)&(gcbo~=boot_ir.histogram)&(gcbo~=boot_ir.histogrammenu);
               t_series = gauss_dist_series;
            end;
            %
            num_row = 1;
            num_col = 1;
            num_a = 1;
            for i=1:size(a_vec,2);
               if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
                  %
                  % Plotting the empirical distributions of A using t-ratios
                  %
                  [pos,bplot] = parm_dist(pos,['a-' num2str(num_col,'%0.0f') '.' num2str(num_row,'%0.0f') '-plot-'],['Density for A(' num2str(num_col,'%0.0f') ',' num2str(num_row,'%0.0f') ') parameter (bootstrapped t-value)'],['Bootstrapped A_{' num2str(num_col,'%0.0f') num2str(num_row,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],tm.A(num_col,num_row),tm.A(num_col,num_row),tm.std_A(num_col,num_row),tm,curr_ini,boot_ir,my_T,t_series,a_t_dist(:,num_a),1,numcells,col,rep);
                  param_plot = [param_plot bplot];
                  create_twodee = 1;
                  num_a = num_a+1;
               end;
               if num_col==tm.n;
                  num_col = 1;
                  num_row = num_row+1;
               else;
                  num_col = num_col+1;
               end;
            end;
         end;
      end;
   end;
   %
   clear('a_vec','a_t_dist');
   %
   % check if we should plot B parameters
   %
   if isempty(tm.b_num(tm.b_num==get(boot_ir.graphtype,'Value')))==0;
      if dist_type==2;
         num_row = 1;
         num_col = 1;
         for i=1:size(b_vec,2);
            if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
               %
               % plotting empirical distrbutions for B
               %
               [pos,bplot] = parm_dist(pos,['b-' num2str(num_col,'%0.0f') '.' num2str(num_row,'%0.0f') '-plot-'],['Density for B(' num2str(num_col,'%0.0f') ',' num2str(num_row,'%0.0f') ') parameter (bootstrapped B)'],['Bootstrapped B_{' num2str(num_col,'%0.0f') num2str(num_row,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped B distribution'],tm.B_0(num_col,num_row),tm.B_0(num_col,num_row),tm.std_B_0(num_col,num_row),tm,curr_ini,boot_ir,my_T,[],b_vec(b_val:t_val,i),1,numcells,col,rep);
               param_plot = [param_plot bplot];
            end;
            if num_col==tm.n;
               num_col = 1;
               num_row = num_row+1;
            else;
               num_col = num_col+1;
            end;
         end;
      else;
         %
         % 2D plots based on t-values
         %
         if isempty(b_t_dist)==0;
            %
            % construct the asymptotic distribution for B based on t-value
            %
            if isempty(t_series)==1;
               if (size(b_t_dist,2)>0)&(gcbo~=boot_ir.histogram)&(gcbo~=boot_ir.histogrammenu);
                  t_series = gauss_dist_series;
               end;
            end;
            %
            num_row = 1;
            num_col = 1;
            num_b = 1;
            for i=1:size(b_vec,2);
               if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
                  %
                  % Plotting the empirical distributions of A using t-ratios
                  %
                  [pos,bplot] = parm_dist(pos,['b-' num2str(num_col,'%0.0f') '.' num2str(num_row,'%0.0f') '-plot-'],['Density for B(' num2str(num_col,'%0.0f') ',' num2str(num_row,'%0.0f') ') parameter (bootstrapped t-value)'],['Bootstrapped B_{' num2str(num_col,'%0.0f') num2str(num_row,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],tm.B_0(num_col,num_row),tm.B_0(num_col,num_row),tm.std_B_0(num_col,num_row),tm,curr_ini,boot_ir,my_T,t_series,b_t_dist(:,num_b),1,numcells,col,rep);
                  param_plot = [param_plot bplot];
                  create_twodee = 1;
                  num_b = num_b+1;
               end;
               if num_col==tm.n;
                  num_col = 1;
                  num_row = num_row+1;
               else;
                  num_col = num_col+1;
               end;
            end;
         end;
      end;
   end;
   %
   clear('b_vec','b_t_dist','t_series');
   %
   if curr_ini.external==0;
      if tm.structural_df>0;
         if ((gcbo==boot_ir.display)|(gcbo==boot_ir.displaymenu))&(get(boot_ir.pq_plot,'Value')==1);
            set(newplot,'Visible','on');
         end;
         set(thisplot,'Visible','on');
      end;
      %
      % display parameter distributions
      %
      if isempty(param_plot)==0;
         set(param_plot,'Visible','on');
      end;
   else;
      stats = [];
      file_names = '';
      my_const_model = get(boot_ir.displaymenu,'UserData');
      if my_const_model(1)==1;
         this_mod = 'no.constant';
      elseif my_const_model(2)==1;
         this_mod = 'restricted.constant';
      elseif my_const_model(3)==1;
         this_mod = 'constant';
      elseif my_const_model(4)==1;
         this_mod = 'restricted.trend';
      elseif my_const_model(5)==1;
         this_mod = 'trend';
      end;
      if tm.structural_df>0;
         if (gcbo==boot_ir.histogram)|(gcbo==boot_ir.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-ir-hist-boot-' tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            file2 = '';
         else;
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-ir-boot-' tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            if get(boot_ir.pq_plot,'Value')==1;
               file2 = [curr_ini.simulatedir tm.modelfile tm.testtype '-ir-boot-pqplots-' tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            else;
               file2 = '';
            end;
         end;
         if strcmp(file2,'')==0;
            set(0,'CurrentFigure',newplot);
            stats = autosavefigure(newplot,file2);
            %
            set(0,'CurrentFigure',thisplot);
            stats = [stats autosavefigure(thisplot,file)];
            file_names = strvcat(file2,file);
         else;
            set(0,'CurrentFigure',thisplot);
            stats = autosavefigure(thisplot,file);
            file_names = file;
         end;
      end;
      for i=1:size(param_plot,2);
         if (gcbo==boot_ir.histogram)|(gcbo==boot_ir.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile '-ir-hist-boot-' get(param_plot(1,i),'Tag') tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         else;
            file = [curr_ini.simulatedir tm.modelfile '-ir-boot-' get(param_plot(1,i),'Tag') tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         end;
         set(0,'CurrentFigure',param_plot(1,i));
         stats = [stats autosavefigure(param_plot(1,i),file)];
         file_names = strvcat(file_names,file);
      end;
      %
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   %
   % case simulate
   %
case 'simulate'
   tm.ir_run = 1;
   set(ir_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_ir.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_ir.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_ir.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_ir.simulate,'UserData',rep);
   blocksize = get(boot_ir.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_ir.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_ir.block,'Value')) '-'];
   end;
   %
   trim_val = get(boot_ir.trim_estimates,'Value');
   if trim_val>1;
      trim_str = get(boot_ir.trim_estimates,'String');
      trim_p = strrep(trim_str(trim_val,:),'%','');
      trim_p = mystr2num(trim_p)/200;
      low_bval = ceil(trim_p*rep)+1;
      high_bval = rep+1-low_bval;
   else;
      low_bval = 1;
      high_bval = rep;
   end;
   %
   % compute original impulse responses and standard errors if not already done
   %
   if ((isfield(tm,'ir')==0)|(isempty(tm.ir)==1))&(isempty(tm.B_0)==0);
      if curr_ini.method(1,1)==1;
         [ir,stdvec,betair,betair_std,abort] = impulses_vlaar_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.gamma,tm.C,tm.dC_theta,tm.h,tm.S,tm.R_mat,tm.R_l,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,0);
         if strcmp(abort,'cancel')==0;
            tm.ir = ir;
            tm.orig_ir = ir;
            tm.stdvec = stdvec;
            tm.betair = betair;
            tm.orig_betair = betair;
            tm.betair_std = betair_std;
         end;
      elseif curr_ini.method(1,2)==1;
         [ir,stdvec,betair,betair_std,abort] = impulses_warne_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.C,tm.dB_theta,tm.h,tm.S,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,0);
         if strcmp(abort,'cancel')==0;
            tm.ir = ir;
            tm.orig_ir = ir;
            tm.stdvec = stdvec;
            tm.betair = betair;
            tm.orig_betair = betair;
            tm.betair_std = betair_std;
         end;
      end;
      for i=1:size(ir,2);
         for j=1:tm.n*tm.n;;
            if abs(tm.stdvec(j,i))<1.0e-008;
               tm.stdvec(j,i) = 0;
            end;
         end;
      end;
      if isempty(tm.betair)==0;
         for i=1:size(tm.betair,2);
            for j=1:tm.r*tm.n;
               if abs(tm.betair_std(j,i))<1.0e-008;
                  tm.betair_std(j,i) = 0;
               end;
            end;
         end;
      end;
   end;
   if isfield(tm,'signshock')==1;
      H = change_ir_signs(tm.signshock,tm.orig_B_0,tm.n);
      tm.ir = kron(H',eye(tm.n))*tm.orig_ir;
      if isempty(tm.betair)==0;
         tm.betair = kron(H',eye(tm.r))*tm.orig_betair;
      end;
   end;
   %
   % initialize
   %
   if tm.structural_df>0;
      ir_test = zeros(rep,1);
   else;
      ir_test = [];
   end;
   a_vec = zeros(rep,tm.n*tm.n);
   a_t_dist = zeros(rep,size(tm.std_A(tm.std_A>0),1));
   b_vec = zeros(rep,tm.n*tm.n);
   b_t_dist = zeros(rep,size(tm.std_B_0(tm.std_B_0>0),1));
   abort = '';
   draw = 1;
   save_draw = 1;
   showprog = get(boot_ir.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_ir.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Impulse Response Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for structural parameters...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for structural parameters...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for structural parameters...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for structural parameters...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'ir-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   if get(boot_ir.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   %
   % replicating
   %
   prev_sample_status = 0;
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_ir.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            if prev_sample_status==1;
               randn('state',sum(100*clock));
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = tm.B_0*Epr;
         else;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               rand('state',sum(100*clock)+draw);
            end;
            if prev_sample_status==1;
               rand('state',sum(100*clock));
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_ir.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % create new sample
      %
      boot = bootstrap_sample(tm,tm.beta,Epr);
      %
      % Estimate model with bootstrapped data
      %
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
      if tm.cointvalue==1;
         %
         % estimate beta under restrictions
         %
         if tm.restrict(1,2)==1;
            [beta,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,my_T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
         end;
         %
         % estimate remaining parameters
         %
         if tm.r>0;
            alpha = (S_01*beta)/(beta'*S_11*beta);
            if isempty(boot.Z2)==0;
               Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
               Z3 = [boot.Z2;beta'*boot.Z1];
            else;
               Psi = [];
               Z3 = beta'*boot.Z1;
            end;
            Theta = [Psi alpha];
            epsilon = boot.Z0-(Theta*Z3);
         else;
            alpha = [];
            if isempty(boot.Z2)==0;
               Psi = (M_02/M_22);
               Z3 = boot.Z2;
               Theta = Psi;
               epsilon = boot.Z0-(Theta*Z3);
            else;
               Psi = [];
               Z3 = [];
               Theta = [];
               epsilon = boot.Z1;
            end;
         end;
         Omega = (1/my_T)*epsilon*epsilon';
         if isempty(Z3)==0;
            inv_Z3 = eye(size(Z3,1))/(Z3*Z3');
            Sigma_theta = kron(inv_Z3,Omega);
         else;
            Sigma_theta = [];
         end;
         %
         if tm.restrict(1,1)==1;
            %
            % collect restrictions on alpha
            %
            if draw==1;
               file_G = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               G = loaddata(file_G);
               [Rmat_alpha,rvec_alpha] = rmatrix(G,tm.n,tm.r);
               dfalpha = size(G,1);
               if isempty(boot.Z2)==0;
                  Rmat_alpha = [zeros(dfalpha,size(boot.Z2,1)*tm.n) Rmat_alpha];
               end;
            end;
            %
            % estimate under alpha restrictions
            %
            if curr_ini.reestbeta==0;
               [Theta,Sigma_theta,infomat,newabort] = linrest(boot.Z0,Z3,Theta,Rmat_alpha,rvec_alpha,0);
            else;
               [Theta,Sigma_theta,beta,stdbeta,Z3,infomat,newabort] = alpha_beta_restrict(boot.Z0,boot.Z1,boot.Z2,Z3,beta,Theta,Rmat_alpha,rvec_alpha,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile,0);
            end;
            epsilon = boot.Z0-(Theta*Z3);
            Omega = (1/my_T)*epsilon*epsilon';
            g2 = size(Theta,2);
            alpha = Theta(:,g2-tm.r+1:g2);
            if g2>tm.r;
               Psi = Theta(:,1:g2-tm.r);
            else;
               Psi = [];
            end;
         end;
         %
         % estimate C under restrictions
         %
         if tm.restrict(1,3)==1;
            if draw==1;
               file_C = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               G = loaddata(file_C);
               [Rmat_C,rvec_C] = rmatrix(G,tm.n,tm.n);
            end;
            %
            % estimate under C restrictions
            %
            [Theta,Sigma_theta,beta,stdbeta,C,Sigma_C,num_c_rest,num_a_rest,infomat,newabort] = c_restrict(boot.Z0,boot.Z1,boot.Z2,tm.restrict,beta,Theta,Rmat_C,rvec_C,tm.p,tm.pe,tm.d,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,0);
            g2 = size(Theta,2);
            if tm.r>0;
               alpha = Theta(:,g2-tm.r+1:g2);
               if g2>tm.r;
                  Z3 = [boot.Z2;beta'*boot.Z1];
                  Psi = Theta(:,1:g2-tm.r);
               else;
                  Z3 = beta'*boot.Z1;
                  Psi = [];
               end;
            else;
               alpha = [];
               Psi = Theta;
               Z3 = boot.Z2;
            end;
            epsilon = boot.Z0-(Theta*Z3);
            Omega = (1/my_T)*epsilon*epsilon';
         end;
      else;
         %
         % set up the parameter estimates
         %
         alpha = (S_01*beta)/(beta'*S_11*beta);
         if isempty(boot.Z2)==0;
            Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
            Z3 = [boot.Z2;beta'*boot.Z1];
         else;
            Psi = [];
            Z3 = beta'*boot.Z1;
         end;
         Theta = [Psi alpha];
         epsilon = boot.Z0-(Theta*Z3);
         Omega = (1/my_T)*epsilon*epsilon';
         inv_Z3 = eye(size(Z3,1))/(Z3*Z3');
         Sigma_theta = kron(inv_Z3,Omega);
      end;
      %
      % Estimate structural model
      %
      if curr_ini.method(1,1)==1;
         [boot_status,new_abort,B_0,S,gamma,Sigma_B0,infomat,R_l,R_mat,rank_test] = vlaar(tm,tm.type,Psi,alpha,beta,epsilon,boot.Z1,boot.Z2,[],1,0);
         if (boot_status==0)|(boot_status==2);
            epsilon = (B_0/chol(Omega)')*epsilon;
            epsilon_v = epsilon;
            if strcmp(tm.type,'short_run')==1;
               [A,Sigma_A,C,dC_theta,Sigma_B0_adj] = amat_sr_vlaar(B_0,Sigma_B0,Psi,alpha,beta,epsilon,boot.Z1,boot.Z2,tm.p,tm.d,1,Sigma_theta);
            else;
               [A,Sigma_A,C,dC_theta,Sigma_B0_adj] = amat_lr_vlaar(B_0,Sigma_B0,S,R_mat,R_l,gamma,Psi,alpha,beta,epsilon,boot.Z1,boot.Z2,tm.p,tm.d,1,Sigma_theta);
            end;
            %
            % tests and standard errors of A and B0
            %
            if tm.structural_df>0;
               Omega_r = B_0*B_0';
               L_r = -my_T*(log(det(Omega_r))+sum(diag((Omega_r\Omega))));
               L_u = -my_T*(log(det(Omega))+tm.n);
               LR_B0 = (L_u-L_r);
               if curr_ini.sscorrect==1;
                  LR_B0 = ((my_T-tm.df)/(my_T*tm.structural_df))*LR_B0;
               end;
            else;
               LR_B0 = [];
            end;
            std_B_0 = vecinv(sqrt(abs(diag(Sigma_B0_adj))),tm.n);
            std_A = vecinv(sqrt(abs(diag(Sigma_A))),tm.n);
            %
            % estimate impulse responses
            %
            [ir,stdvec,betair,betair_std,newabort] = impulses_vlaar_fcn(tm,tm.type,B_0,Sigma_B0,gamma,C,dC_theta,tm.h,S,R_mat,R_l,Psi,alpha,beta,Sigma_theta,0);
         end;
      elseif curr_ini.method(1,2)==1;
         old_epsilon = epsilon;
         [boot_status,new_abort,B_0,Psi,alpha,beta,C,A,stdbeta,S,Sigma_theta,Sigma_B0,Sigma_B0_adj,Sigma_A,infomat,R_mat,epsilon_v,num_rest,dC_theta,dB_theta,max_case,rank_test] = warne(tm,tm.type,tm.keep_rest,tm.del_rest,tm.use_psi_rest,Psi,alpha,beta,epsilon,boot.Z0,boot.Z1,boot.Z2,[],1,0,tm.max_case);
         if (boot_status==0)|(boot_status==2);
            epsilon = (B_0/chol(Omega)')*epsilon_v;
            Omega = B_0*B_0';
            %
            % tests and standard errors of A and B0
            %
            if tm.structural_df>0;
               L_r = loglike_fcn(B_0,epsilon_v);
               L_u = loglike(old_epsilon);
               LR_B0 = 2*(L_u-L_r);
               if curr_ini.sscorrect==1;
                  LR_B0 = ((my_T-tm.df)/(my_T*tm.structural_df))*LR_B0;
               end;
            else;
               LR_B0 = [];
            end;
            std_B_0 = vecinv(sqrt(abs(diag(Sigma_B0_adj))),tm.n);
            std_A = vecinv(sqrt(abs(diag(Sigma_A))),tm.n);
            %
            % estimate impulse responses
            %
            [ir,stdvec,betair,betair_std,newabort] = impulses_warne_fcn(tm,tm.type,B_0,Sigma_B0,C,dB_theta,tm.h,S,Psi,alpha,beta,Sigma_theta,0);
         end;
      end;
      %
      % Collecting results
      %
      if (boot_status==0)|(boot_status==2);
         %
         % fix matrices with standard errors in case there are numerical problems
         %
         for i=1:tm.n;
            for j=1:tm.n;
               if abs(tm.A(i,j))<1.0e-008;
                  std_A(i,j) = 0;
               end;
               if abs(tm.B_0(i,j))<1.0e-008;
                  std_B_0(i,j) = 0;
               end;
            end;
         end;
         %
         if tm.structural_df>0;
            ir_test(draw,1) = LR_B0;
         end;
         for i=1:size(ir,2);
            for j=1:size(ir,1);
               if (abs(tm.stdvec(j,i))<1.0e-008)|(abs(stdvec(j,i))<1.0e-008);
                  stdvec(j,i) = 1000000;
               end;
            end;
         end;
         if isempty(betair)==0;
            for i=1:size(betair,2);
               for j=1:size(betair,1);
                  if (abs(tm.betair_std(j,i))<1.0e-008)|(abs(betair_std(j,i))<1.0e-008);
                     betair_std(j,i) = 1000000;
                  end;
               end;
            end;
         end;
         ir_boot.draws(save_draw).ir = ir;
         ir_boot.draws(save_draw).ir_t_dist = (ir-tm.ir)./stdvec;
         if isempty(betair)==0;
            ir_boot.draws(save_draw).betair = betair;
            ir_boot.draws(save_draw).betair_t_dist = (betair-tm.betair)./betair_std;
         end;
         %
         % save these to file
         %
         if (draw==rep)|(isint(draw/100));
            if tm.const_model(1)==1;
               ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(round(draw/100),'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(round(draw/100),'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(round(draw/100),'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(round(draw/100),'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(round(draw/100),'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            end;
            save(ir_file,'ir_boot');
            clear('ir_boot');
            save_draw = 0;
         end;
         %
         a_vec(draw,:) = vec(A)'; % tm.std_A>0
         a_t_dist(draw,:) = ( (A(tm.std_A>0) - tm.A(tm.std_A>0)) ./ std_A(tm.std_A>0) )';
         b_vec(draw,:) = vec(B_0)';
         b_t_dist(draw,:) = ( (B_0(tm.std_B_0>0) - tm.B_0(tm.std_B_0>0)) ./ std_B_0(tm.std_B_0>0) )';
         draw = draw+1;
         save_draw = save_draw+1;
         prev_sample_status = 0;
      else;
         prev_sample_status = 1;
      end;
   end;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat(' ','The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(b_vec)==0);
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Impulse Response Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_ir.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         set(boot_ir.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_ir.bootstrapgraphmenu,'Enable','on');
      end;
      testfile = strrep(epsfile,'.mat',['-' 'ir-data.mat']);
      %
      test_data = ir_test;
      save(testfile,'test_data');
      clear('test_data');
      %
      set(boot_ir.bootstrapgraphmenu,'UserData',testfile);
      %
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the test and the t-ratios and save to file
      %    i is variable, j is shock
      %
      for i=1:tm.n;
         for j=1:tm.n;
            this_text = strvcat(' ','Sorting impulse responses for: ',['   variable: ' strtrim(tm.myvars(i,:))],['   shock:    ' strtrim(tm.myshocks(j,:))],'Please hold!');
            set(waitf.text,'String',this_text);
            elem = i+(tm.n*(j-1));
            if isempty(betair)==0;
               elem_beta = i+(tm.r*(j-1));
            end;
            k = 1;
            search_file = 1;
            ir_var_shock = zeros(rep,size(tm.ir,2));
            ir_var_shock_t = zeros(rep,size(tm.ir,2));
            if (isempty(betair)==0)&(i<=tm.r);
               betair_var_shock = zeros(rep,size(tm.ir,2));
               betair_var_shock_t = zeros(rep,size(tm.ir,2));
            end;
            num_rep = 0;
            while search_file==1;
               %
               % get filename where we may have saved data temporarily
               %
               if tm.const_model(1)==1;
                  ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
               end;
               if fileexist(ir_file)==1;
                  my_boot = load(ir_file);
                  for i1=1:size(my_boot.ir_boot.draws,2);
                     num_rep = num_rep+1;
                     % alternative num_rep = i1+(100*(k-1))
                     ir_var_shock(num_rep,:) = my_boot.ir_boot.draws(i1).ir(elem,:);
                     ir_var_shock_t(num_rep,:) = my_boot.ir_boot.draws(i1).ir_t_dist(elem,:);
                     if (isempty(betair)==0)&(i<=tm.r);
                        betair_var_shock(num_rep,:) = my_boot.ir_boot.draws(i1).betair(elem_beta,:);
                        betair_var_shock_t(num_rep,:) = my_boot.ir_boot.draws(i1).betair_t_dist(elem_beta,:);
                     end;
                  end;
                  clear('my_boot');
                  k = k+1;
               else;
                  search_file = 0;
               end;
            end;
            %
            % sort data and store in new file
            %
            for i1=1:size(tm.ir,2);
               ir_var_shock(:,i1) = sort(ir_var_shock(:,i1));
               ir_var_shock_t(:,i1) = sort(ir_var_shock_t(:,i1));
               if (isempty(betair)==0)&(i<=tm.r);
                  betair_var_shock(:,i1) = sort(betair_var_shock(:,i1));
                  betair_var_shock_t(:,i1) = sort(betair_var_shock_t(:,i1));
               end;
            end;
            if tm.const_model(1)==1;
               new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               new_file = [curr_ini.simulatedir  tm.modelfile '-sort.' num2str(i,'%0.0f') '.' num2str(j,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            end;
            est_ir = tm.ir(elem,:);
            std_ir = tm.stdvec(elem,:);
            if isempty(betair)==1;
               save(new_file,'ir_var_shock','ir_var_shock_t','est_ir','std_ir');
            else;
               if i<=tm.r;
                  est_betair = tm.betair(elem_beta,:);
                  std_betair = tm.betair_std(elem_beta,:);
                  save(new_file,'ir_var_shock','ir_var_shock_t','est_ir','std_ir','betair_var_shock','betair_var_shock_t','est_betair','std_betair');
               else;
                  save(new_file,'ir_var_shock','ir_var_shock_t','est_ir','std_ir');
               end;
            end;
         end;
      end;
      %
      clear('ir_var_shock','ir_var_shock_t');
      if isempty(betair)==0;
         clear('betair_var_shock','betair_var_shock_t');
      end;
      %
      % delete the temporary files
      %
      search_file = 1;
      k = 1;
      while search_file==1;
         %
         % get filename where we may have saved data temporarily
         %
         if tm.const_model(1)==1;
            ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            ir_file = [curr_ini.simulatedir  tm.modelfile '-draw.' num2str(k,'%0.0f') '-ir-boot-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         if fileexist(ir_file)==1;
            delete_file_fcn(ir_file);
            k = k+1;
         else;
            search_file = 0;
         end;
      end;
      %
      % sort the test
      %
      if tm.structural_df>0;
         ir_test_sorted = sort(ir_test);
      else;
         ir_test_sorted = [];
      end;
      clear('ir_test');
      %
      % sort the A estimates
      %
      for i=1:size(a_vec,2);
         a_vec(:,i) = sort(a_vec(:,i));
      end;
      %
      for i=1:size(a_t_dist,2);
         a_t_dist(:,i) = sort(a_t_dist(:,i));
      end;
      %
      % sort the B_0 estimates
      %
      for i=1:size(b_vec,2);
         b_vec(:,i) = sort(b_vec(:,i));
      end;
      %
      for i=1:size(b_t_dist,2);
         b_t_dist(:,i) = sort(b_t_dist(:,i));
      end;
      %
      set(boot_ir.rep,'UserData',rep);
      set(boot_ir.obs,'UserData',my_T);
      set(boot_ir.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      if curr_ini.sscorrect==1;
         add_test = 'F';
         add_str = [',' num2str(my_T-tm.df,'%0.0f')];
         test_str = ['F(' num2str(tm.structural_df,'%0.0f') add_str ')'];
      else;
         add_test = 'LR';
         add_str = '';
         test_str = ['chi-square(' num2str(tm.structural_df,'%0.0f') ')'];
      end;
      %
      % save full simulations
      %
      if get(boot_ir.save,'Value')==1;
         this_text = strvcat(' ',['Saving bootstrapped A and B estimates and ' add_test ' tests to disk...'],'Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         if tm.structural_df>0;
            save(full_mat,'Number','ir_test_sorted','a_vec','a_t_dist','b_vec','b_t_dist');
         else;
            save(full_mat,'Number','a_vec','a_t_dist','b_vec','b_t_dist');
         end;
         set(boot_ir.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_ir.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % dealing with the size of the test
      %
      boot_size = [];
      boot_pval = [];
      if tm.structural_df>0;
         this_text = strvcat(' ',['Determining the empirical size of the ' add_test ' test...'],'Please hold!');
         set(waitf.text,'String',this_text);
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],tm.structural_df*ones(5,1),(my_T-tm.df)*ones(5,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],tm.structural_df*ones(5,1));
         end;
         for i=1:5;
            for j=1:rep;
               if my_cv(i,1)>=ir_test_sorted(rep+1-j,1);
                  break;
               end;
            end;
            if (j<rep)|(my_cv(i,1)>=ir_test_sorted(1,1));
               boot_size = [boot_size (rep+1-j)/rep];
            else;
               boot_size = [boot_size 0];
            end;
         end;
         if tm.T==my_T;
            this_text = strvcat(' ',['Determining the empirical p-value of the ' add_test ' test...'],'Please hold!');
            set(waitf.text,'String',this_text);
            for j=1:rep;
               if tm.LR_B0>=ir_test_sorted(rep+1-j);
                  break;
               end;
            end;
            boot_pval = j/rep;
         end;
      end;
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      sp_str = spacestr(curr_ini.decimals-2);
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      if tm.structural_df>0;
         res_str = strvcat(res_str,['                      ' add_test ' test for ' num2str(tm.structural_df,'%0.0f') ' restrictions on the structural model'],'                      --------------------------------------------------',' ',['    80%   ' sp_str '     90%   ' sp_str '     95%   ' sp_str '     98%   ' sp_str '     99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
         max_std = sqrt( (1/rep)*sum( ( ir_test_sorted - ( (1/rep)*sum(ir_test_sorted) ) ).*( ir_test_sorted - ( (1/rep)*sum(ir_test_sorted) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],ir_test_sorted(my_80,1),ir_test_sorted(my_90,1),ir_test_sorted(my_95,1),ir_test_sorted(my_975,1),ir_test_sorted(my_99,1),(1/rep)*sum(ir_test_sorted),max_std));
         if curr_ini.sscorrect==1;
            res_str = strvcat(res_str,['From the ' test_str ' distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            res_str = strvcat(res_str,['From the ' test_str ' distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),tm.structural_df,sqrt(2*tm.structural_df)),' ');
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level    20%      10%       5%       2%       1%',sprintf('            %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1))),' ');
         if isempty(boot_pval)==0;
            res_str = strvcat(res_str,'                      Empirical p-value','                      -----------------',' ',[add_test '(' num2str(tm.structural_df,'%0.0f') add_str ')  = ' num2str(tm.LR_B0,prt_tex)],['p-value = ' num2str(boot_pval,prt_tex)],' ');
         end;
      end;
      %
      % dealing with A
      %
      my_cv_min(1,1) = ceil(0.1*rep);
      my_cv_min(2,1) = ceil(0.05*rep);
      my_cv_min(3,1) = ceil(0.025*rep);
      my_cv_min(4,1) = ceil(0.01*rep);
      my_cv_min(5,1) = ceil(0.005*rep);
      my_cv_max(1,1) = floor(0.9*rep);
      my_cv_max(2,1) = floor(0.95*rep);
      my_cv_max(3,1) = floor(0.975*rep);
      my_cv_max(4,1) = floor(0.99*rep);
      my_cv_max(5,1) = floor(0.995*rep);
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap statistics for A parameters','   -------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['parameter    ML Estimate   ' sp_str '    Mean   ' sp_str '     Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
               check_prt = 1;
            end;
            est_val = tm.A(col_val,row_val);
            mean_val = (1/(high_bval+1-low_bval))*sum(a_vec(low_bval:high_bval,i));
            median_val = a_vec(ceil(0.5*rep),i);
            std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (a_vec(low_bval:high_bval,i)-mean_val).*(a_vec(low_bval:high_bval,i)-mean_val) ) );
            norm_A = (1/std_val)*(a_vec(low_bval:high_bval,i)-mean_val);
            skew_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A);
            kurt_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A.*norm_A);
            %
            res_str = strvcat(res_str,sprintf(['A(%2.0f,%2.0f)      ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],col_val,row_val,est_val,mean_val,median_val,std_val,skew_val,kurt_val));
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap confidence intervals for A parameters using bootstrapped A','   --------------------------------------------------------------------',' ',['parameter    ' sp_str '       80%        ' sp_str sp_str '           90%         ' sp_str sp_str '          95%         ' sp_str sp_str '          98%         ' sp_str sp_str '          99%']);
               check_prt = 1;
            end;
            c_vals = zeros(10,1);
            for j=1:5;
               lower_val = a_vec(my_cv_min(j,1),i);
               upper_val = a_vec(my_cv_max(j,1),i);
               c_vals(1+(2*(j-1)),1) = lower_val;
               c_vals(2+(2*(j-1)),1) = upper_val;
            end;
            res_str = strvcat(res_str,sprintf(['A(%2.0f,%2.0f)    [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],col_val,row_val,c_vals));
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap confidence intervals for A parameters using bootstrapped t-values','   ---------------------------------------------------------------------------',' ',['parameter    ' sp_str '       80%        ' sp_str sp_str '           90%         ' sp_str sp_str '          95%         ' sp_str sp_str '          98%         ' sp_str sp_str '          99%']);
               check_prt = 1;
            end;
            c_vals = zeros(10,1);
            for j=1:5;
               %
               % notice that the lower limit uses the upper t-value and the upper limit the lower t-value
               %
               lower_val = tm.A(col_val,row_val)-(a_t_dist(my_cv_max(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_A(col_val,row_val));
               upper_val = tm.A(col_val,row_val)-(a_t_dist(my_cv_min(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_A(col_val,row_val));
               c_vals(1+(2*(j-1)),1) = lower_val;
               c_vals(2+(2*(j-1)),1) = upper_val;
            end;
            res_str = strvcat(res_str,sprintf(['A(%2.0f,%2.0f)    [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],col_val,row_val,c_vals));
            check_prt = check_prt+1;
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      res_str = strvcat(res_str,'==============================================================',' ');
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if B coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap statistics for B parameters','   -------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['parameter    ML Estimate   ' sp_str '    Mean   ' sp_str '     Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
               check_prt = 1;
            end;
            est_val = tm.B_0(col_val,row_val);
            mean_val = (1/(high_bval+1-low_bval))*sum(b_vec(low_bval:high_bval,i));
            median_val = b_vec(ceil(0.5*rep),i);
            std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (b_vec(low_bval:high_bval,i)-mean_val).*(b_vec(low_bval:high_bval,i)-mean_val) ) );
            norm_A = (1/std_val)*(b_vec(low_bval:high_bval,i)-mean_val);
            skew_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A);
            kurt_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A.*norm_A);
            res_str = strvcat(res_str,sprintf(['B(%2.0f,%2.0f)      ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],col_val,row_val,est_val,mean_val,median_val,std_val,skew_val,kurt_val));
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if B coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap confidence intervals for B parameters using bootstrapped B','   --------------------------------------------------------------------',' ',['parameter    ' sp_str '       80%        ' sp_str sp_str '           90%         ' sp_str sp_str '          95%         ' sp_str sp_str '          98%         ' sp_str sp_str '          99%']);
               check_prt = 1;
            end;
            c_vals = zeros(10,1);
            for j=1:5;
               lower_val = b_vec(my_cv_min(j,1),i);
               upper_val = b_vec(my_cv_max(j,1),i);
               c_vals(1+(2*(j-1)),1) = lower_val;
               c_vals(2+(2*(j-1)),1) = upper_val;
            end;
            res_str = strvcat(res_str,sprintf(['B(%2.0f,%2.0f)    [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],col_val,row_val,c_vals));
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               res_str = strvcat(res_str,'   Bootstrap confidence intervals for B parameters using bootstrapped t-values','   ---------------------------------------------------------------------------',' ',['parameter    ' sp_str '       80%        ' sp_str sp_str '           90%         ' sp_str sp_str '          95%         ' sp_str sp_str '          98%         ' sp_str sp_str '          99%']);
               check_prt = 1;
            end;
            c_vals = zeros(10,1);
            for j=1:5;
               lower_val = tm.B_0(col_val,row_val)-(b_t_dist(my_cv_max(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_B_0(col_val,row_val));
               upper_val = tm.B_0(col_val,row_val)-(b_t_dist(my_cv_min(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_B_0(col_val,row_val));
               c_vals(1+(2*(j-1)),1) = lower_val;
               c_vals(2+(2*(j-1)),1) = upper_val;
            end;
            res_str = strvcat(res_str,sprintf(['B(%2.0f,%2.0f)    [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],col_val,row_val,c_vals));
            check_prt = check_prt+1;
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         res_str = strvcat(res_str,' ');
      end;
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-ir-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc tm.file_df num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      %
      % write to tex-file
      %
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      if tm.structural_df>0;
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,['\\multicolumn{7}{c}{' add_test ' test for ' num2str(tm.structural_df,'%0.0f') ' restrictions on the structural model} \\\\\n']);
         fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         max_std = sqrt( (1/rep)*sum( ( ir_test_sorted - ( (1/rep)*sum(ir_test_sorted) ) ).*( ir_test_sorted - ( (1/rep)*sum(ir_test_sorted) ) ) ) );
         fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],ir_test_sorted(my_80,1),ir_test_sorted(my_90,1),ir_test_sorted(my_95,1),ir_test_sorted(my_975,1),ir_test_sorted(my_99,1),(1/rep)*sum(ir_test_sorted),max_std);
         fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
         fprintf(f_id,['\\multicolumn{7}{c}{From the ' test_str ' distribution we have the following:} \\\\\n']);
         if curr_ini.sscorrect==1;
            fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),tm.structural_df,sqrt(2*tm.structural_df));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Nominal size & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,' & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         if isempty(boot_pval)==0;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
            fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
            fprintf(f_id,[' & ' add_test '(%0.0f' add_str ') = ' prt_tex ' \\\\ \n'],tm.structural_df,tm.LR_B0);
            fprintf(f_id,[' & $p$-value = ' prt_tex ' \\\\ \n'],boot_pval);
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
               fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap statistics for $A$ parameters using simulated} \\\\\n');
               fprintf(f_id,['\\multicolumn{7}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
               fprintf(f_id,'parameter & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
               check_prt = 1;
            end;
            est_val = tm.A(col_val,row_val);
            mean_val = (1/(high_bval+1-low_bval))*sum(a_vec(low_bval:high_bval,i));
            median_val = a_vec(ceil(0.5*rep),i);
            std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (a_vec(low_bval:high_bval,i)-mean_val).*(a_vec(low_bval:high_bval,i)-mean_val) ) );
            norm_A = (1/std_val)*(a_vec(low_bval:high_bval,i)-mean_val);
            skew_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A);
            kurt_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A.*norm_A);
            fprintf(f_id,['$A_{%0.0f%0.0f}$ & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],col_val,row_val,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt==1;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
               fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $A$ parameters using empirical $A$ distribution} \\\\\n');
               fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
               check_prt = 1;
            end;
            A_str = ['$A_{' num2str(col_val,'%0.0f') num2str(row_val,'%0.0f') '}$'];
            for j=1:5;
               lower_val = a_vec(my_cv_min(j,1),i);
               upper_val = a_vec(my_cv_max(j,1),i);
               A_str = [A_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
            end;
            fprintf(f_id,[A_str ' \\\\\n']);
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(a_vec,2);
         %
         % test if A coefficient is free
         %
         if isalmostequal(min(a_vec(:,i)),max(a_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
               fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $A$ parameters using empirical $t$-value distribution} \\\\\n');
               fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
               check_prt = 1;
            end;
            A_str = ['$A_{' num2str(col_val,'%0.0f') num2str(row_val,'%0.0f') '}$'];
            for j=1:5;
               lower_val = tm.A(col_val,row_val)-(a_t_dist(my_cv_max(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_A(col_val,row_val));
               upper_val = tm.A(col_val,row_val)-(a_t_dist(my_cv_min(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_A(col_val,row_val));
               A_str = [A_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
            end;
            fprintf(f_id,[A_str ' \\\\\n']);
            check_prt = check_prt+1;
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if B coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
               fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap statistics for $B$ parameters using simulated} \\\\\n');
               fprintf(f_id,['\\multicolumn{7}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
               fprintf(f_id,'parameter & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
               check_prt = 1;
            end;
            est_val = tm.B_0(col_val,row_val);
            mean_val = (1/(high_bval+1-low_bval))*sum(b_vec(low_bval:high_bval,i));
            median_val = b_vec(ceil(0.5*rep),i);
            std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (b_vec(low_bval:high_bval,i)-mean_val).*(b_vec(low_bval:high_bval,i)-mean_val) ) );
            norm_A = (1/std_val)*(b_vec(low_bval:high_bval,i)-mean_val);
            skew_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A);
            kurt_val = (1/(high_bval+1-low_bval))*sum(norm_A.*norm_A.*norm_A.*norm_A);
            fprintf(f_id,['$B_{%0.0f%0.0f}$ & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],col_val,row_val,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt==1;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if B coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
               fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $B$ parameters using empirical $A$ distribution} \\\\\n');
               fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
               check_prt = 1;
            end;
            A_str = ['$B_{' num2str(col_val,'%0.0f') num2str(row_val,'%0.0f') '}$'];
            for j=1:5;
               lower_val = b_vec(my_cv_min(j,1),i);
               upper_val = b_vec(my_cv_max(j,1),i);
               A_str = [A_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
            end;
            fprintf(f_id,[A_str ' \\\\\n']);
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      row_val = 1;
      col_val = 1;
      check_prt = 0;
      for i=1:size(b_vec,2);
         %
         % test if B coefficient is free
         %
         if isalmostequal(min(b_vec(:,i)),max(b_vec(:,i)))==0;
            if check_prt==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
               fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $B$ parameters using empirical $t$-value distribution} \\\\\n');
               fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
               check_prt = 1;
            end;
            A_str = ['$B_{' num2str(col_val,'%0.0f') num2str(row_val,'%0.0f') '}$'];
            for j=1:5;
               lower_val = tm.B_0(col_val,row_val)-(b_t_dist(my_cv_max(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_B_0(col_val,row_val));
               upper_val = tm.B_0(col_val,row_val)-(b_t_dist(my_cv_min(j,1),check_prt)*sqrt(tm.T/my_T)*tm.std_B_0(col_val,row_val));
               A_str = [A_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
            end;
            fprintf(f_id,[A_str ' \\\\\n']);
            check_prt = check_prt+1;
         end;
         if col_val==tm.n;
            row_val = row_val+1;
            col_val = 1;
         else;
            col_val = col_val+1;
         end;
      end;
      if check_prt>0;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
      fclose(f_id);
      %
      set(boot_ir.display,'UserData',ir_test_sorted);
      set(boot_ir.histogram,'UserData',a_vec);
      set(boot_ir.full,'UserData',a_t_dist);
      set(boot_ir.clock,'UserData',b_vec);
      set(boot_ir.summary,'UserData',b_t_dist);
      clear('ir_test_sorted','a_vec','a_t_dist','b_vec','b_t_dist');
      %
      if curr_ini.noprint==0;
         set(boot_ir.output,'Enable','on');
      end;
      set(boot_ir.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_ir.summary,'Enable','on');
      set(boot_ir.display,'Enable','on');
      set(boot_ir.displaymenu,'Enable','on');
      set(boot_ir.histogram,'Enable','on');
      set(boot_ir.histogrammenu,'Enable','on');
      set(boot_ir.matfilebutton,'Enable','on');
      set(boot_ir.matfilemenu,'Enable','on');
      set(boot_ir.ir_display,'Enable','on');
      set(boot_ir.ir_displaymenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.ir_run = 0;
   set(ir_boot_gui,'Visible','on');
case 'done'
   if tm.ir_run==0;
      set(boot_ir.done,'UserData','done');
      pid = get(boot_ir.filemenu,'UserData');
      if isempty(pid)==1;
         delete(ir_boot_gui);
      else;
         close(ir_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(ir_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_ir.filemenu,'UserData',pid);
         set(ir_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(ir_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_ir.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_ir.done,'UserData','done');
end;

%
% end of ir_bootstrap.m
%
