%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of            %
%          impulse response functions                            %
%                                                                %
%          Function: ir_graphdlg                                 %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_m: structure with model info           %
%                                                                %
%          Output:                                               %
%          	            h: handle                                %
%                                                                %
%          This version:        May 4, 2006                      %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = ir_graphdlg(selector,c_m)

if strcmp(selector,'init')==1;
   thisexit = 0;
   curr_ini = find_inisettings;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   c_m.ini = curr_ini;
else
   thisexit = 1;
   ir_graphgui = findobj('Type','figure','Tag','IRGraphDlg');
   ir_graph = get(ir_graphgui,'UserData');
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      ir_graphgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','ir_graphdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-341)/2 (realscrsz(4)-140)/2 341 140], ...
         'Tag','IRGraphDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Graph Impulse Responses', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','ir_graphdlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(ir_graphgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 130],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 80 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(getfield(mycons,'irfunctionbig_image'),[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      ir_graph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 50 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',['Impulse responses from period 0 to ' num2str(c_m.h,'%0.0f')], ...
         'HorizontalAlignment','left', ...
         'Tag','SampleText');

      if strcmp(c_m.freq,'q')==1;
         set(ir_graph.icon,'String',strrep(get(ir_graph.icon,'String'),'period','quarter'));
      elseif strcmp(c_m.freq,'m')==1;
         set(ir_graph.icon,'String',strrep(get(ir_graph.icon,'String'),'period','month'));
      end;

      %
      % Select variable
      %

      ir_graph.variables = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 80 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'UserData',c_m, ...
         'String','Select Shock:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');


      ir_graph.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[105 20 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',c_m.myshocks, ...
         'HorizontalAlignment','center', ...
         'Tag','GraphPopup',...
         'Value',1);

      %
      % Create graph button
      %

      ir_graph.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','ir_graphdlg showgraph', ...
         'Enable','on', ...
         'UserData','working', ...
         'Tag','Done');

      %
      %  Done button
      %

      ir_graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','ir_graphdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(ir_graphgui,'UserData',ir_graph,...
         'HandleVisibility','callback');
   case 'showgraph'
      c_m = get(ir_graph.variables,'UserData');
      curr_ini = c_m.ini;
      curr_val = get(ir_graph.popup,'Value');
      all_shocks = get(ir_graph.popup,'String');
      curr_shock = strtrim(all_shocks(curr_val,:));
      if curr_val<c_m.n;
         set(ir_graph.popup,'Value',curr_val+1);
      else;
         set(ir_graph.popup,'Value',1);
      end;
      if curr_ini.colors==1;
         colorstr1 = [1 0 0];
         colorstr2 = (1/255)*[255 255 177];
         colorstr3 = [0 1 0];
         colorstr4 = [0 0 1];
      else;
         colorstr1 = [0 0 0];
         colorstr2 = [0.6 0.6 0.6];
         colorstr3 = [0 0 0];
         colorstr4 = [0 0 0];
      end;
      my_unit = 'Year';
      if strcmp(c_m.freq,'q')==1;
         my_unit = 'Quarter';
      elseif strcmp(c_m.freq,'m')==1;
         my_unit = 'Month';
      end;
      %
      ir_handles = [];
      realscrsz = get(0,'ScreenSize');
      pos = [(realscrsz(3)-512)/2 (realscrsz(4)-384)/2];
      x_val = (0:1:c_m.h);
      for i=1:c_m.n;
         elem = i+(c_m.n*(curr_val-1));
         %
         ir_handle = figure('Units','pixels', ...
            'Position',[pos 512 384], ...
            'Menubar','none', ...
            'Toolbar','none', ...
            'NumberTitle','off', ...
            'Tag',['ir-' strrep(strtrim(c_m.myvars(i,:)),' ','') '.' strrep(curr_shock,' ','') '-'], ...
            'Visible','off', ...
            'Name',['Impulse Responses - ' strtrim(c_m.myvars(i,:)) ' from ' curr_shock]);
         ir_handles = [ir_handles ir_handle];
         %
         % default figure properties
         %
         setfigureproperties(ir_handle);
         %
         % Fixing position for next graph
         %
         pos = [pos(1,1)+22 pos(1,2)-22];
         if pos(1,1)>(realscrsz(3)-512);
            pos = [0 realscrsz(4)-454];
         end;
         if pos(1,2)>(realscrsz(4)-454);
            pos = [0 realscrsz(4)-454];
         elseif pos(1,2)<32;
            pos = [0 realscrsz(4)-454];
         end;
         %
         % extracting series to graph
         %
         ir = c_m.ir(elem,:);
         upper_c = c_m.upper(elem,:);
         lower_c = c_m.lower(elem,:);
         %
         if isfield(c_m,'mean_ir')==1;
            mean_ir = c_m.mean_ir(elem,:);
            median_ir = c_m.median_ir(elem,:);
            set(ir_handle,'Tag',['boot-' get(ir_handle,'Tag')]);
         end;
         %
         % Using a patch to display the confidence region
         %
         my_p = patch([x_val reverse(x_val)],[upper_c reverse(lower_c)],colorstr2);
         set(my_p,'FaceColor',colorstr2,'EdgeColor',colorstr2,'Tag','confpatch','LineWidth',1);
         hold('on');
         %
         % checking if we should draw a zero line
         %
         %
         y_lim = get(gca,'Ylim');
         if y_lim(1)>0;
            set(gca,'YLim',[-y_lim(1) y_lim(2)]);
         elseif y_lim(2)<0;
            set(gca,'YLim',[y_lim(1) -y_lim(2)]);
         elseif y_lim(1)==0;
            set(gca,'YLim',[-y_lim(2)/2  y_lim(2)]);
         elseif y_lim(2)==0;
            set(gca,'YLim',[y_lim(1) -y_lim(1)/2]);
         end;
         y_lim = get(gca,'YLim');
         add_y_lim = (abs(y_lim(2))+abs(y_lim(1)))/20;
         set(gca,'YLim',y_lim+[-add_y_lim add_y_lim]);
         plot([0 c_m.h],[0 0],'-','LineWidth',1,'Color',[0 0 0]);
         hold('on');
         if isfield(c_m,'mean_ir')==1;
            my_median = plot(x_val,median_ir,':','LineWidth',1,'Color',colorstr3);
            hold('on');
            my_mean = plot(x_val,mean_ir,'-.','LineWidth',1,'Color',colorstr4);
            hold('on');
         end;
         my_ir = plot(x_val,ir,'-','LineWidth',1,'Color',colorstr1,'Tag',['ir-' strtrim(c_m.myvars(i,:)) '-' curr_shock]);
         hold('on');
         %
         if istexgreek(curr_shock)==1;
            this_shock = ['\' curr_shock];
         else;
            this_shock = curr_shock;
         end;
         set(gca,'XLim',[0 c_m.h],'Layer','top');
         title_str = ['Responses in ' strtrim(c_m.myvars(i,:)) ' from a unit shock to ' this_shock ' with ' num2str(c_m.c,'%0.0f') ' % confidence region'];
         setaxesfonts('Title',title_str,'Xlabel',my_unit);
         %
         if isfield(c_m,'mean_ir')==0;
            myleg = legend_fcn([my_ir my_p],'Response','Confidence',1);
         else;
            myleg = legend_fcn([my_ir my_mean my_median my_p],'ML estimate','Bootstrap mean','Bootstrap median',['Confidence' c_m.ir_legend_str],1);
         end;
         setaxesfonts(myleg);
         set(gca,'UserData',myleg);
         toolbar_fcn(gca);
      end;
      hold('off');
      %
      % impulse responses to cointegration relations
      %
      if (isempty(c_m.betair)==0)&(c_m.cointvalue==1);
         for i=1:c_m.r;
            elem = i+(c_m.r*(curr_val-1));
            %
            ir_handle = figure('Units','pixels', ...
               'Position',[pos 512 384], ...
               'Menubar','none', ...
               'Toolbar','none', ...
               'NumberTitle','off', ...
               'Tag',['ir-coint' num2str(i,'%0.0f') '.' strrep(curr_shock,' ','') '-'], ...
               'Visible','off', ...
               'Name',['Impulse Responses - coint(' num2str(i,'%0.0f') ') from ' curr_shock]);
            ir_handles = [ir_handles ir_handle];
            %
            % default figure properties
            %
            setfigureproperties(ir_handle);
            %
            % Fixing position for next graph
            %
            pos = [pos(1,1)+22 pos(1,2)-22];
            if pos(1,1)>(realscrsz(3)-512);
               pos = [0 realscrsz(4)-454];
            end;
            if pos(1,2)>(realscrsz(4)-454);
               pos = [0 realscrsz(4)-454];
            elseif pos(1,2)<32;
               pos = [0 realscrsz(4)-454];
            end;
            %
            % extracting series to graph
            %
            ir = c_m.betair(elem,:);
            upper_c = c_m.betair_upper(elem,:);
            lower_c = c_m.betair_lower(elem,:);
            %
            if isfield(c_m,'mean_betair')==1;
               mean_betair = c_m.mean_betair(elem,:);
               median_betair = c_m.median_betair(elem,:);
               set(ir_handle,'Tag',['boot-' get(ir_handle,'Tag')]);
            end;
            %
            % Using a patch to display the confidence region
            %
            my_p = patch([x_val reverse(x_val)],[upper_c reverse(lower_c)],colorstr2);
            set(my_p,'FaceColor',colorstr2,'EdgeColor',colorstr2,'Tag','confpatch','LineWidth',1);
            hold('on');
            %
            % checking if we should draw a zero line
            %
            %
            y_lim = get(gca,'Ylim');
            if y_lim(1)>0;
               set(gca,'YLim',[-y_lim(1) y_lim(2)]);
            elseif y_lim(2)<0;
               set(gca,'YLim',[y_lim(1) -y_lim(2)]);
            elseif y_lim(1)==0;
               set(gca,'YLim',[-y_lim(2)/2  y_lim(2)]);
            elseif y_lim(2)==0;
               set(gca,'YLim',[y_lim(1) -y_lim(1)/2]);
            end;
            y_lim = get(gca,'YLim');
            add_y_lim = (abs(y_lim(2))+abs(y_lim(1)))/20;
            set(gca,'YLim',y_lim+[-add_y_lim add_y_lim]);
            plot([0 c_m.h],[0 0],'-','LineWidth',1,'Color',[0 0 0]);
            hold('on');
            if isfield(c_m,'mean_betair')==1;
               my_median = plot(x_val,median_betair,':','LineWidth',1,'Color',colorstr3);
               hold('on');
               my_mean = plot(x_val,mean_betair,'-.','LineWidth',1,'Color',colorstr4);
               hold('on');
            end;
            my_ir = plot(x_val,ir,'-','LineWidth',1,'Color',colorstr1,'Tag',['ir-coint(' num2str(i,'%0.0f') ')-' curr_shock]);
            hold('on');
            %
            if istexgreek(curr_shock)==1;
               this_shock = ['\' curr_shock];
            else;
               this_shock = curr_shock;
            end;
            set(gca,'XLim',[0 c_m.h],'Layer','top');
            title_str = ['Responses in coint(' num2str(i,'%0.0f') ') from a unit shock to ' this_shock ' with ' num2str(c_m.c,'%0.0f') ' % confidence region'];
            setaxesfonts('Title',title_str,'Xlabel',my_unit);
            %
            if isfield(c_m,'mean_bir')==0;
               myleg = legend_fcn([my_ir my_p],'Response','Confidence',1);
            else;
               myleg = legend_fcn([my_ir my_mean my_median my_p],'ML estimate','Bootstrap mean','Bootstrap median',['Confidence' c_m.ir_legend_str],1);
            end;
            setaxesfonts(myleg);
            set(gca,'UserData',myleg);
            toolbar_fcn(gca);
         end;
         hold('off');
      end;
      if curr_ini.external==0;
         set(ir_handles,'Visible','on');
      else;
         stats = [];
         file_names = '';
         for i=1:size(ir_handles,2);
            if isfield(c_m,'mean_ir')==0;
               file = [c_m.outputdir c_m.modelfile '-' get(ir_handles(1,i),'Tag') num2str(c_m.n) '.' num2str(c_m.r)];
            else;
               file = [curr_ini.simulatedir c_m.modelfile '-' get(ir_handles(1,i),'Tag') num2str(c_m.n) '.' num2str(c_m.r) '-' num2str(c_m.my_T) '.' num2str(c_m.rep) '-' c_m.boot_model_type];
            end;
            set(0,'CurrentFigure',ir_handles(1,i));
            stats = [stats autosavefigure(ir_handles(1,i),file)];
            file_names = strvcat(file_names,file);
         end;
         if isempty(stats)==0;
            for i=1:size(stats,2);
               if stats(i)==0;
                  autoshowfigure(strtrim(file_names(i,:)));
               end;
            end;
         end;
      end;
   case 'done'
      set(ir_graph.done,'UserData','done');
      set(ir_graphgui,'UserData',ir_graph);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(ir_graphgui,'Name') ' ' fix_filepath([pwd '\icons\irfunction.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(ir_graph.icon,'UserData',pid);
      end;
   end;
   %
   set(ir_graphgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(ir_graphgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(ir_graph.done);
   end;
   waitfor(ir_graph.done,'UserData','done');
end;

if nargout==1;
   h = ir_graphgui;
end;

%
% end of ir_graphdlg.m
%
