%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes value of the maximized log likelihood        %
%          function for a normal distribution when Omega         %
%          can differ from (1/T)*epsilon*epsilon'. This          %
%          may happens in overidentified structural models.      %
%                                                                %
%          Function: loglike_fcn                                 %
%                                                                %
%          Input:                                                %
%                       B: nxn decomposition of Omega            %
%                       epsilon: nxT matrix with residuals       %
%                                                                %
%          Output:                                               %
%          	            lnl: value of log likelihood function    %
%                       logdetOmega: the value of the natural    %
%                            logaritm of the determinant of      %
%                            Omega                               %
%                                                                %
%          This version:        April 13, 2005                   %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2005          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [lnl,logdetOmega] = loglike_fcn(B,epsilon)

[n T] = size(epsilon);
Omega = B*B';
Omega_inv = Omega\eye(n);

lnl = -(T/2)*(n*log(2*pi)+log(det(Omega)))-((1/2)*sum(diag(Omega_inv*epsilon*epsilon')));

if nargout==2;
   logdetOmega = log(det(Omega));
end;

%
% end of loglike_fcn.m
%
