%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes multivariate Ljung-Box test for serial       %
%             correlation                                        %
%                                                                %
%          Function: portmanteau_fcn                             %
%                                                                %
%          Input:                                                %
%                       epsilon: nxT matrix with residuals       %
%                       p: number of lags in the VAR             %
%                                                                %
%          Output:                                               %
%          	            autocorrvec: vector with results         %
%                       df: string with degrees of freedom       %
%                                                                %
%          This version:        January 30, 2006                 %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [autocorrvec,df] = portmanteau_fcn(epsilon,p,tm)

curr_ini = find_inisettings;

[n T] = size(epsilon);
h = floor(T/8);
if h<=p;
   h = p+1;
end;

C0 = (1/T)*epsilon*epsilon';
autocorrvec = 0;
for i=1:h;
   Ci = (1/T)*epsilon(:,1+i:T)*epsilon(:,1:T-i)';
   autocorrvec = autocorrvec+(((1/(T-i))*trace(Ci'*inverse(C0)*Ci*inverse(C0))));
end;
autocorrvec = T*(T+2)*autocorrvec;
df = strvcat(num2str(n*n*(h-p)),num2str(h));

if curr_ini.lbcorrect==1;
   bc = 1+((size(tm.Z1,1)+size(tm.Z2,1))/(2*(T-size(tm.Z1,1)-size(tm.Z2,1))));
   autocorrvec = autocorrvec/bc;
end;

pval = chis_cdf(autocorrvec,n*n*(h-p));
autocorrvec = [autocorrvec 1-pval];

%
% end of portmanteau_fcn.m
%
