function [c_bands,p_median] = posterior_confidence_bands(tm,gibbs_results,r)

%
% Determines X% confidence bands for all parameters from the full posterior
% and the median for each individual parameter
%

c_bands = [];
low_lev = (1-(tm.cbs/(100)))/2;
upp_lev = 1-low_lev;
low_lev = ceil(tm.save_draws*low_lev);
upp_lev = floor(tm.save_draws*upp_lev);
%
% Parameters on the deterministics
%
if tm.d>0;
   c_bands.delta_lower = zeros(size(gibbs_results.posterior(1).delta));
   c_bands.delta_upper = zeros(size(gibbs_results.posterior(1).delta));
   p_median.delta = zeros(size(gibbs_results.posterior(1).delta));
   for i=1:tm.n;
      for j=1:tm.d;
         delta_ij = zeros(tm.save_draws,1);
         for k=1:tm.save_draws;
            delta_ij(k,1) = gibbs_results.posterior(k).delta(i,j);
         end;
         delta_ij = sort(delta_ij);
         p_median.delta(i,j) = median(delta_ij);
         c_bands.delta_lower(i,j) = delta_ij(low_lev,1);
         c_bands.delta_upper(i,j) = delta_ij(upp_lev,1);
      end;
   end;
end;
%
% Parameters on lagged endogenous and stationary exogenous
%
if size(tm.Z2,1)>tm.d;
   c_bands.Gamma_lower = zeros(size(gibbs_results.posterior(1).Gamma));
   c_bands.Gamma_upper = zeros(size(gibbs_results.posterior(1).Gamma));
   p_median.Gamma = zeros(size(gibbs_results.posterior(1).Gamma));
   for i=1:tm.n;
      for j=1:size(tm.Z2,1)-tm.d;
         Gamma_ij = zeros(tm.save_draws,1);
         for k=1:tm.save_draws;
            Gamma_ij(k,1) = gibbs_results.posterior(k).Gamma(i,j);
         end;
         Gamma_ij = sort(Gamma_ij);
         p_median.Gamma(i,j) = median(Gamma_ij);
         c_bands.Gamma_lower(i,j) = Gamma_ij(low_lev,1);
         c_bands.Gamma_upper(i,j) = Gamma_ij(upp_lev,1);
      end;
   end;
end;
%
% Alpha and Beta parameters
%
if r>0;
   c_bands.alpha_lower = zeros(tm.n,r);
   c_bands.alpha_upper = zeros(tm.n,r);
   p_median.alpha = zeros(tm.n,r);
   for i=1:tm.n;
      for j=1:r;
         alpha_ij = zeros(tm.save_draws,1);
         for k=1:tm.save_draws;
            alpha_ij(k,1) = gibbs_results.posterior(k).alpha(i,j);
         end;
         alpha_ij = sort(alpha_ij);
         p_median.alpha(i,j) = median(alpha_ij);
         c_bands.alpha_lower(i,j) = alpha_ij(low_lev,1);
         c_bands.alpha_upper(i,j) = alpha_ij(upp_lev,1);
      end;
   end;
   c_bands.beta_lower = zeros(size(gibbs_results.posterior(1).beta));
   c_bands.beta_upper = zeros(size(gibbs_results.posterior(1).beta));
   p_median.beta = zeros(size(gibbs_results.posterior(1).beta));
   for i=1:size(gibbs_results.posterior(1).beta,1);
      for j=1:r;
         beta_ij = zeros(tm.save_draws,1);
         for k=1:tm.save_draws;
            beta_ij(k,1) = gibbs_results.posterior(k).beta(i,j);
         end;
         beta_ij = sort(beta_ij);
         p_median.beta(i,j) = median(beta_ij);
         c_bands.beta_lower(i,j) = beta_ij(low_lev,1);
         c_bands.beta_upper(i,j) = beta_ij(upp_lev,1);
      end;
   end;
   %
   % marginal alpha and beta
   %
   if isfield(gibbs_results.posterior(1),'alpha_n')==1;
      c_bands.alpha_n_lower = zeros(tm.n,r);
      c_bands.alpha_n_upper = zeros(tm.n,r);
      p_median.alpha_n = zeros(tm.n,r);
      for i=1:tm.n;
         for j=1:r;
            alpha_ij = zeros(tm.save_draws,1);
            for k=1:tm.save_draws;
               alpha_ij(k,1) = gibbs_results.posterior(k).alpha_n(i,j);
            end;
            alpha_ij = sort(alpha_ij);
            p_median.alpha_n(i,j) = median(alpha_ij);
            c_bands.alpha_n_lower(i,j) = alpha_ij(low_lev,1);
            c_bands.alpha_n_upper(i,j) = alpha_ij(upp_lev,1);
         end;
      end;
      c_bands.beta_n_lower = zeros(size(gibbs_results.posterior(1).beta));
      c_bands.beta_n_upper = zeros(size(gibbs_results.posterior(1).beta));
      p_median.beta_n = zeros(size(gibbs_results.posterior(1).beta));
      for i=1:size(gibbs_results.posterior(1).beta,1);
         for j=1:r;
            beta_ij = zeros(tm.save_draws,1);
            for k=1:tm.save_draws;
               beta_ij(k,1) = gibbs_results.posterior(k).beta_n(i,j);
            end;
            beta_ij = sort(beta_ij);
            p_median.beta_n(i,j) = median(beta_ij);
            c_bands.beta_n_lower(i,j) = beta_ij(low_lev,1);
            c_bands.beta_n_upper(i,j) = beta_ij(upp_lev,1);
         end;
      end;
   end;
end;
%
% Omega estimates
%
c_bands.Omega_lower = zeros(tm.n,tm.n);
c_bands.Omega_upper = zeros(tm.n,tm.n);
p_median.Omega = zeros(tm.n,tm.n);
for i=1:tm.n;
   for j=i:tm.n;
      Omega_ij = zeros(tm.save_draws,1);
      for k=1:tm.save_draws;
         Omega_ij(k,1) = gibbs_results.posterior(k).Omega(i,j);
      end;
      Omega_ij = sort(Omega_ij);
      p_median.Omega(i,j) = median(Omega_ij);
      p_median.Omega(j,i) = p_median.Omega(i,j);
      c_bands.Omega_lower(i,j) = Omega_ij(low_lev,1);
      c_bands.Omega_lower(j,i) = Omega_ij(low_lev,1);
      c_bands.Omega_upper(i,j) = Omega_ij(upp_lev,1);
      c_bands.Omega_upper(j,i) = Omega_ij(upp_lev,1);
   end;
end;

%
% end of posterior_confidence_bands.m
%
