function [hl,labelhandles] = make_legend(legh,ha,Kids,lstrings,legendpos,ud)
%MAKE_LEGEND Make legend given parent axes, kids, and strings
%
%   MAKE_LEGEND(...,ud) is called from the resizeFcn.  In this case
%   just update the position of the legend pieces instead of recreating
%   it from scratch.

hf = get(ha,'parent'); % Parent figure

% Get the legend info structure from the inputs
info = legend_info(ha,hf,Kids,lstrings);

% Remember current state
hfold = find_gcf(ha);
haold = find_gca(ha);
punits=get(hf,'units');
aunits=get(ha,'units');
if strncmp(get(hf,'NextPlot'),'replace',7),
  set(hf,'NextPlot','add')
  oldNextPlot = get(hf,'NextPlot');
else
  oldNextPlot = '';
end
set(ha,'units','points');
set(hf,'units','points');

% Determine size of legend in figure points
fontn = get(ha,'fontname');
fonts = get(ha,'fontsize');
fonta = get(ha,'fontangle');
fontw = get(ha,'fontweight');
cap = get(ha,'Position');

if iscompiled==1;
   toolbar = get(gcf,'UserData');
   if isempty(toolbar)==0;
      myfonts = get(toolbar.new,'UserData');
      if isempty(myfonts)==0;
         if isfield(myfonts,'parent')==1;
            num_parents = size(myfonts.parent,2);
            fontpos = 0;
            for i=1:num_parents;
               if myfonts.parent(i)==ha;
                  fontpos = i;
                  break;
               end;
            end;
            if fontpos>0;
               fontn = myfonts.font(fontpos).fontname;
               fonts = myfonts.font(fontpos).fontsize;
               fonta = myfonts.font(fontpos).fontangle;
               fontw = myfonts.font(fontpos).fontweight;
            end;
         end;
      end;
   else;
      myfonts = get(ha,'UserData');
      if isempty(myfonts)==0;
         if isfield(myfonts,'parent')==1;
            num_parents = size(myfonts.parent,2);
            fontpos = 0;
            for i=1:num_parents;
               if myfonts.parent(i)==ha;
                  fontpos = i;
                  break;
               end;
            end;
            if fontpos>0;
               fontn = myfonts.font(fontpos).fontname;
               fonts = myfonts.font(fontpos).fontsize;
               fonta = myfonts.font(fontpos).fontangle;
               fontw = myfonts.font(fontpos).fontweight;
            end;
         end;
      end;
   end;
else;
   myfonts = get(ha,'UserData');
   if isempty(myfonts)==0;
      if isfield(myfonts,'parent')==1;
         num_parents = size(myfonts.parent,2);
         fontpos = 0;
         for i=1:num_parents;
            if myfonts.parent(i)==ha;
               fontpos = i;
               break;
            end;
         end;
         if fontpos>0;
            fontn = myfonts.font(fontpos).fontname;
            fonts = myfonts.font(fontpos).fontsize;
            fonta = myfonts.font(fontpos).fontangle;
            fontw = myfonts.font(fontpos).fontweight;
         end;
      end;
   end;
end;

% Symbols are the size of 3 numbers
h = text(0,0,'123','fontname',fontn,'fontsize',fonts,...
         'fontangle',fonta,'fontweight',fontw);
set(h,'units','points','visible','off');
ext = get(h,'extent');
lsym = ext(3);
loffset = lsym/3;
delete(h);

% Make box big enough to handle longest string
h=text(0,0,{info.label},'fontname',fontn,'fontsize',fonts,...
       'fontangle',fonta,'fontweight',fontw);
set(h,'units','points','visible','off');
ext = get(h,'extent');
width = ext(3);
height = ext(4)/size(get(h,'string'),1);
margin = height*0.075;
delete(h);

llen = width + loffset*3 + lsym; 
lhgt = ext(4) + 2*margin;

% Reset axis if it had be resized to that getposition works
if nargin==6,
  set(ha,'units','normalized','position',ud.PlotPosition)
  set(ha,'units','points')
end
  
[lpos,axpos] = getposition(legh,ha,legendpos,llen,lhgt);

% Shrink axes if necessary
ud.PlotHandle = ha;
set(ha,'units','normalized')
ud.PlotPosition = get(ha,'position'); % Remember old axes position
set(ha,'units','points')
ud.legendpos = legendpos;
if ~isempty(axpos)
  set(ha,'Position',axpos)
end
set(ha,'units','normalized')
ud.AxesPosition = get(ha,'position');

% Create legend object
if find_gcf ~= hf & nargin<6, figure(hf); end
if strcmp(get(ha,'color'),'none')
  acolor = get(hf,'color');
else
  acolor = get(ha,'color');
end

if nargin<6
  % Create legend axes and DeleteProxy object (an
  % invisible text object in target axes) so that the 
  % legend will get deleted correctly.
  ud.DeleteProxy = text('parent',ha,'visible','off', ...
                        'tag','LegendDeleteProxy',...
                        'handlevisibility','off');
  hl=axes('units','points','position',lpos,'box','on','drawmode', ...
        'fast','nextplot','add','xtick',[-1],'ytick',[-1], ...
        'xticklabel','','yticklabel','','xlim',[0 1],'ylim',[0 1], ...
        'clipping','on','color',acolor,'tag','legend','view',[0 90],...
        'climmode',get(ha,'climmode'),'clim',get(ha,'clim'),...
        'deletefcn','legend_fcn(''DeleteLegend'')');
  set(hl,'units','normalized')
  setappdata(hl,'NonDataObject',[]); % Used by DATACHILDREN.M
  ud.LegendPosition = get(hl,'position');
  set(ud.DeleteProxy,'deletefcn','eval(''delete(get(gcbo,''''userdata''''))'','''')');
  set(ud.DeleteProxy,'userdata',hl);
else
  hl = ud.LegendHandle;
  labelhandles = ud.LabelHandles;
  set(hl,'units','points','position',lpos);
  set(hl,'units','normalized')
  ud.LegendPosition = get(hl,'position');
end
  
texthandles = [];
objhandles = [];

nstack = length(info);
nrows = size(char(info.label),1);

% draw text one on chunk so that the text spacing is good
label = char(info.label);
top = (1-max(1,size(label,1)))/2;
if nargin<6
  texthandles = text('parent',hl,'units','data',...
       'position',[1-(width+loffset)/llen,1-(1-top)/(nrows+1)],...
       'string',char(info.label),...
       'fontname',fontn,'fontweight',fontw,...
       'fontsize',fonts,'fontangle',fonta,...
       'ButtonDownFcn','moveaxis_var');
else
  texthandles = ud.LabelHandles(1);
  set(texthandles,'units','data',...
      'position',[1-(width+loffset)/llen,1-(1-top)/(nrows+1)],...
      'fontname',fontn,'fontsize',fonts);
end
     
ext = get(texthandles,'extent');
centers = linspace(ext(4)-ext(4)/nrows,0,nrows)+ext(4)/nrows/2 + 0.4*(1-ext(4));
edges = linspace(ext(4),0,nrows+1) + 0.4*(1-ext(4));
indent = [1 1 -1 -1 1] * ext(4)/nrows/7.5;

hpos = 2;
r = 1;
for i=1:nstack
  % draw lines with markers like this: --*--
  if strcmp(info(i).objtype,'line')
     if ~strcmp(info(i).linetype,'none')
        if nargin<6
          p = line('parent',hl,'xdata',(loffset+[0 lsym])/llen,...
                   'ydata',[centers(r) centers(r)],...
                   'linestyle',info(i).linetype,...
                   'marker','none',...
                   'color',info(i).edgecol, ...
                   'linewidth',info(i).lnwidth,...
                   'ButtonDownFcn','moveaxis_var');
        else
          p = ud.LabelHandles(hpos);
          set(p,'xdata',(loffset+[0 lsym])/llen,...
                'ydata',[centers(r) centers(r)]);
          hpos = hpos+1;
        end
     else
       p = [];
     end
     if ~strcmp(info(i).marker,'none')
       if nargin<6
         p = [p;line('parent',hl,'xdata',(loffset+lsym/2)/llen,...
                    'ydata',centers(r),...
                    'color',info(i).edgecol, ...
                    'linestyle','none',...
                    'linewidth',info(i).lnwidth,...
                    'marker',info(i).marker,...
                    'markeredgecolor',info(i).markedge,...
                    'markerfacecolor',info(i).markface,...
                    'markersize',info(i).marksize,...
                    'ButtonDownFcn','moveaxis_var')];
       else
         p2 = ud.LabelHandles(hpos);
         set(p2,'xdata',(loffset+lsym/2)/llen,...
               'ydata',centers(r));
         hpos = hpos+1;
         p = [p;p2];
       end
     end

  % draw patches
  elseif strcmp(info(i).objtype,'patch')  | strcmp(info(i).objtype,'surface')
     % Adjusting ydata to make a thinner box will produce nicer
     % results if you use patches with markers.
     if nargin<6
       p = patch('parent',hl,'xdata',(loffset+[0 lsym lsym 0 0])/llen,...
                  'ydata',[edges(r) edges(r) edges(r+1) edges(r+1) edges(r)]-indent,...
                  'linestyle',info(i).linetype,...
                  'edgecolor',info(i).edgecol, ...
                  'facecolor',info(i).facecol,...
                  'linewidth',info(i).lnwidth,...
                  'marker',info(i).marker,...
                  'markeredgecolor',info(i).markedge,...
                  'markerfacecolor',info(i).markface,...
                  'markersize',info(i).marksize,...
                  'ButtonDownFcn','moveaxis_var');
     else
       p = ud.LabelHandles(hpos);
       set(p,'xdata',(loffset+[0 lsym lsym 0 0])/llen,...
             'ydata',[edges(r) edges(r) edges(r+1) edges(r+1) edges(r)]-indent);
       hpos = hpos+1;
     end
     if strcmp(info(i).facecol,'flat') | strcmp(info(i).edgecol,'flat')
        c = get(Kids(i),'cdata');
        k = min(find(finite(c)));
        if ~isempty(k)
          set(p,'cdata',c(k)*ones(1,5),...
                'cdatamapping',get(Kids(i),'cdatamapping'));
        end
     end
  end
  objhandles = [objhandles;p];
  r = r + max(1,size(info(i).label,1));
end

labelhandles = [texthandles;objhandles];

% Clean up a bit

set(hf,'currentaxes',haold)
set(hf,'units',punits)
set(ha,'units',aunits)
if (hfold ~= hf) & nargin<6, figure(hfold); end
if ~isempty(oldNextPlot)
  set(hf,'nextplot',oldNextPlot)
end
ud.handles = Kids;
ud.lstrings = {info.label};
ud.LabelHandles = labelhandles;
ud.LegendHandle = hl;
set(hl,'ButtonDownFcn','moveaxis_var','interruptible','on', ...
       'busyaction','queue','userdata',ud);

% Make legend resize itself
if isempty(get(hf,'resizefcn')),
  set(hf,'resizefcn','legend_fcn(''ResizeLegend'')')
end

if nargin<6
  PlaceLegendOnTop(hf,hl,ha)
end

if (isequal(hl,legh)==0)&(iscompiled==1);
   set(ha,'UserData',hl);
end;

%
% end of make_legend.m
%
