%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting proportionality       %
%          restrictions on dummy variables, estimate the model   %
%          under proportionality restrictions and test if the    %
%          data is consistent with the restrictions              %
%                                                                %
%          Function: proportionality_dummies_dlg                 %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       cm: current model structure              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            None                                     %
%                                                                %
%          This version:        May 12, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function proportionality_dummies_dlg(selector,cm,curr_ini)

if strcmp(selector,'init')==1;
   tm = cm;
   tm.num_const = tm.ad;
   tm.num_dummies = tm.datad;
   %
   dummy_names = vecstr(tm.deter);
   tm.dummy_names = dummy_names(1+tm.num_const:tm.num_dummies+tm.num_const,:);
   tm.ini = curr_ini;
   tm.realscrsz = get(0,'ScreenSize');
   c_rows = floor(sqrt(tm.num_dummies));
   check_width = 1;
   while check_width==1;
      c_cols = ceil(tm.num_dummies/c_rows);
      height = 125+(c_rows*20)+((c_rows-1)*5);
      width = 40+(150*c_cols)+(5*(c_cols-1));
      if width>tm.realscrsz(3);
         c_rows = c_rows+1;
      else;
         check_width = 0;
      end;
   end;
   if width<300;
      width = 300;
   end;
else;
   pdd = findobj('Type','figure','Tag','PropDlg');
   pdd_graph = get(pdd,'UserData');
   tm = get(pdd_graph.display,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      pdd = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','proportionality_dummies_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','PropDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Proportionality Restrictions', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','proportionality_dummies_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(pdd,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Selection',45,[0.5 1]);

      pdd_graph.icon = show_text([20 height-60 width-40 30],[0 0 0],strvcat('H_0: D_{i_1},...,D_{i_{h}} have proportional parameters','H_A: D_{i_1},...,D_{i_{h}} do not have proportional parameters'),[0 0.5],9);

      pdd_graph.controls = [];
      num = 0;
      for j=1:c_cols;
         for i=1:c_rows;
            num = num+1;
            if num<=tm.num_dummies;
               control = uicontrol('Units','pixels', ...
                  'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
                  'Position',[20+(155*(j-1)) 50+(25*(c_rows-i)) 100 20], ...
                  'FontSize',curr_ini.gui_fontsize, ...
                  'FontName',curr_ini.gui_fontname, ...
                  'FontWeight',curr_ini.gui_fontweight, ...
                  'FontAngle',curr_ini.gui_fontangle, ...
                  'Style','checkbox', ...
                  'Value',0, ...
                  'Enable','on', ...
                  'CallBack','proportionality_dummies_dlg check_boxes', ...
                  'Visible','on', ...
                  'HorizontalAlignment','left', ...
                  'String',strtrim(tm.dummy_names(num,:)), ...
                  'Tag',strtrim(tm.dummy_names(num,:)));
               pdd_graph.controls = [pdd_graph.controls control];
            end;
         end;
      end;

      pdd_graph.display = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-210 20 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','proportionality_dummies_dlg display', ...
         'Enable','off', ...
         'UserData',tm, ...
         'Tag','Done');

      pdd_graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-110 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','proportionality_dummies_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(pdd,'UserData',pdd_graph,...
         'HandleVisibility','callback');

   case 'display'
      set(pdd,'Visible','off');
      drawnow;
      %
      % determine the dummies to select
      %
      sel_dummies = [];
      for i=1:size(pdd_graph.controls,2);
         if get(pdd_graph.controls(1,i),'Value')==1;
            sel_dummies = [sel_dummies i];
         end;
      end;
      sel_dummy_names = tm.dummy_names(sel_dummies,:);
      %
      % compute the tests
      %
      if tm.r>0;
         beta = tm.beta(:,1:tm.r);
      else;
         beta = [];
      end;
      [test,deg_free,pval,phi,phi_std,kappa,kappa_std,delta,delta_std,abort] = proportionality_dummies(tm.epsilon,tm.Z0,tm.Z1,tm.Z2,tm.alpha,beta,tm.Psi,tm.restrict,sel_dummies,tm.num_const,tm.num_dummies,tm.p,tm.pe,tm.q1,tm.q0,tm.df,tm.dcoint,tm.modelsdir,tm.modelfile,curr_ini.convcrit,curr_ini.maxit,curr_ini.reestbeta,curr_ini.sscorrect);
      %
      if strcmp(abort,'cancel')==0;
         %
         % display results
         %
         txt = strvcat(' ',['TESTING PROPORTIONALITY RESTRICTIONS FOR DETERMINISTIC VARIABLES (for rank=' num2str(tm.r) ')']);
         numchar = size(txt,2);
         addtxt = '';
         for i=1:numchar;
            addtxt = strcat(addtxt,'=');
         end;
         txt = strvcat(txt,addtxt,' ');
         txt = strvcat(txt,'  LR-type test statistic','  ~~~~~~~~~~~~~~~~~~~~~~',' ');
         %
         sh_dn = strtrim(sel_dummy_names(1,:));
         for i=2:size(sel_dummy_names,1);
            sh_dn = [sh_dn ', ' strtrim(sel_dummy_names(i,:))];
         end;
         txt = strvcat(txt,['Null Hypothesis:        ' sh_dn ' have proportional parameters']);
         txt = strvcat(txt,['Alternative Hypothesis: ' sh_dn ' do not have proportional parameters'],' ');
         if curr_ini.sscorrect==0;
            txt = strvcat(txt,['LR(' num2str(deg_free,'%0.0f') ')  = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         else;
            txt = strvcat(txt,['F(' num2str(deg_free(1,1),'%0.0f') ',' num2str(deg_free(1,2),'%0.0f') ') = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         end;
         txt = strvcat(txt,['p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
         txt = strvcat(txt,['The proportionality restrictions for ' sh_dn ' are: delta(3) = phi*kappa'',']);
         txt = strvcat(txt,'where phi, asymptotic standard errors and t-ratios is:',' ');
         for i=1:tm.n;
            txt = strvcat(txt,['   ' tm.myvars(i,:) '    ' num2str(phi(i,1),['%' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']) '    (' num2str(phi_std(i,1),['%' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']) ')    [' num2str(inf2nan(phi(i,1)./phi_std(i,1)),['%' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         end;
         sp_str = spacestr(curr_ini.decimals-2);
         txt = strvcat(txt,' ','while kappa'', asymptotic standard errors and t-ratios are:',' ');
         kappa_str = ['       ' strrep(sh_dn,', ',['      ' sp_str])];
         k_str = '     ';
         kstd_str = '     ';
         kt_str = '     ';
         for i=1:size(kappa,1);
            if i<size(kappa,1);
               k_str = [k_str ' ' num2str(kappa(i,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) '     '];
               kstd_str = [kstd_str '(' num2str(kappa_std(i,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ')    '];
               kt_str = [kt_str '[' num2str(inf2nan(kappa(i,1)./kappa_std(i,1)),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']    '];
            else;
               k_str = [k_str ' ' num2str(kappa(i,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])];
               kstd_str = [kstd_str '(' num2str(kappa_std(i,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ')'];
               kt_str = [kt_str '[' num2str(inf2nan(kappa(i,1)./kappa_std(i,1)),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']'];
            end;
         end;
         txt = strvcat(txt,kappa_str,k_str,kstd_str,kt_str,' ');
         txt = strvcat(txt,'For delta(3) we have that:',' ',kappa_str);
         for i=1:tm.n;
            est_str = [' ' tm.myvars(i,:) '  '];
            std_str = blankstr(size(est_str,2));
            t_str = std_str;
            for j=1:size(kappa,1);
               if j<size(kappa,1);
                  est_str = [est_str ' ' num2str(delta(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) '     '];
                  std_str = [std_str '(' num2str(delta_std(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ')    '];
                  t_str = [t_str '[' num2str(inf2nan(delta(i,j)./delta_std(i,j)),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']    '];
               else;
                  est_str = [est_str ' ' num2str(delta(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])];
                  std_str = [std_str '(' num2str(delta_std(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ')'];
                  t_str = [t_str '[' num2str(inf2nan(delta(i,j)./delta_std(i,j)),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']'];
               end;
            end;
            txt = strvcat(txt,est_str,std_str,t_str);
         end;
         txt = strvcat(txt,' ');
         txt = aligntxt(txt);
         if (curr_ini.noprint==0)&(curr_ini.dummytests==1);
            %
            % print results to the outputfile
            %
            print_proportionality_dummies(tm,curr_ini,sel_dummy_names,test,deg_free,pval,phi,phi_std,kappa,kappa_std,delta,delta_std);
         end;
         %
         % display results
         %
         textgui(txt,'Proportionality Restrictions',[(tm.realscrsz(3)-750)/2 (tm.realscrsz(4)-500)/2 750 500],'Results',38);
      end;
      set(pdd,'Visible','on');
      drawnow;
   case 'check_boxes'
      num = 0;
      for i=1:size(pdd_graph.controls,2);
         if get(pdd_graph.controls(1,i),'Value')==1;
            num = num+1;
         end;
      end;
      if num>=2;
         set(pdd_graph.display,'Enable','on');
      else;
         set(pdd_graph.display,'Enable','off');
      end;
   case 'done'
      set(pdd_graph.done,'UserData','done');
      killguipid(pdd);
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(pdd,'Name') ' ' fix_filepath([pwd '\icons\deterprop.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(pdd_graph.icon,'UserData',pid);
      end;
   end;
   %
   set(pdd,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(pdd,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(pdd_graph.done);
   end;
   waitfor(pdd_graph.done,'UserData','done');
end;

%
% end of proportionality_dummies_dlg.m
%
