%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for recursive estimation of           %
%          cointegration relations                               %
%                                                                %
%          Function: recbeta                                     %
%                                                                %
%          Input:                                                %
%          	            R0: nxT matrix                           %
%                       R1: nq1xT matrix                         %
%                       r: cointegration rank                    %
%                                                                %
%          Output:                                               %
%          	            S_00: nxn matrix                         %
%          	            S_01: nxnq1 matrix                       %
%                       S_10: nq1xn matrix                       %
%                       S_11: nq1xnq1 matrix                     %
%                       betat: nq1xr matrix                      %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [S_00,S_01,S_10,S_11,betat] = recbeta(R0,R1,r)

%
% Determine the sample size
%

[n T] = size(R0);
nq1 = size(R1,1);

%
% Compute product moment matrice S_ij
%

S_00 = (1/T)*R0*R0';
S_11 = (1/T)*R1*R1';
S_01 = (1/T)*R0*R1';
S_10 = (1/T)*R1*R0';

%
% Solving the eigenvalue problem
%
% Step 1: Diagonalize S_11
%

[W,rho] = eig(S_11);
rho = diag(rho,0);
[rho2,AscInd] = sort(abs(rho));

nr = size(AscInd,1);
DescInd = zeros(nr,1);
i = 1;
while i<=nr;
   DescInd(i)=AscInd(nr+1-i);
   i =i+1;
end;

%
% Resort eigenvalues and eigenvectors
% in descending order
%

rho = rho(DescInd);
sqrho = sqrt(rho);
rho = diag(rho,0);
sqrho = diag(sqrho,0);
W = W(:,DescInd);

%
% Step 2: Reformulating eigenvalue problem to
%         calculating the eigenvalues for
%
%         adjS_11 = sqS_11*S_10*inverse(S_00)*S_01*sqS_11
%

sqS_11 = W*inverse(sqrho)*W';

adjS_11 = sqS_11*S_10*inverse(S_00)*S_01*sqS_11;

[U,lambda] = eig(adjS_11);

lambda = diag(lambda,0);
[lambda2,AscInd] = sort(abs(lambda));

nr = size(AscInd,1);
DescInd = zeros(nr,1);
i = 1;
while i<=nr;
   DescInd(i)=AscInd(nr+1-i);
   i =i+1;
end;

%
% Resort eigenvalues and eigenvectors
% in descending order
%

lambda = lambda(DescInd);
U = U(:,DescInd);

%
% Renormalize U such that V'S_11V=I
%

V = sqS_11*U;

%
% extract betat
%

betat = real(V(:,1:r));

%
% End of function recbeta.m
%
