function fig_handle = showfig(fig_file)

%
% open figure
%
open(fig_file);

fig_h = findobj('Type','figure')';
fig_handle = 2;

%
% make sure figure is not visible until it's ready for viewing
%
% contextmenus will be fixed via windowbuttonmotionfcn
%
set(fig_handle,'Visible','off','WindowButtonMotionFcn','change_context_menus');
fig_name = get(fig_handle,'Name');
if size(fig_name,2)>=12;
   check_figname = fig_name(1,1:12);
else;
   check_figname = '';
end;
if strcmp(lower(check_figname),'figeditor - ')==0;
   set(fig_handle,'Name',['FigEditor - ' fig_name]);
end;
%
% fix figure
%

ax_obj = findobj(fig_handle,'Type','axes','Visible','off')';
for i=1:size(ax_obj,2);
   set(ax_obj(1,i),'Visible','on');
end;

curr_ini = find_inisettings;

if (curr_ini.use_toolbar_bgcolor==1)&(strcmp(get(fig_handle,'Renderer'),'zbuffer')==1);
   figcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
   figcolor(1) = max(0,figcolor(1));
   figcolor(2) = max(0,figcolor(2));
   figcolor(3) = max(0,figcolor(3));
else;
   figcolor = get(0,'defaultuicontrolbackgroundcolor');
end;

pos = get(fig_handle,'Position');
realscrsz = get(0,'ScreenSize');

%
% center figure on screen and make sure it fits
%

pos = [max(0,(realscrsz(3)-pos(3))/2) max(0,(realscrsz(4)-pos(4))/2) min(pos(3),realscrsz(3)) min(pos(4),realscrsz(4))];
set(fig_handle,'Position',pos);

if iscompiled==1;
   toolbar = get(fig_handle,'UserData');
   if (isempty(toolbar)==0)&(isfield(toolbar,'print')==1)&(ishandle(toolbar.print)==1)&(isfield(toolbar,'box1')==1)&(ishandle(toolbar.box1)==1);
      toolbar_fields = fieldnames(toolbar);
      if isempty(get(toolbar.print,'UserData'))==0;
         myaxes = get(toolbar.print,'UserData');
      else;
         myaxes = [];
      end;
      %
      % delete old toolbar, but store user data from toolbar fields into old_toolbar structure.
      % these values are then reset into user data of new toolbar
      %
      old_toolbar = [];
      for i=1:size(toolbar_fields,1);
         if ishandle(getfield(toolbar,toolbar_fields{i}))==1;
            if isempty(get(getfield(toolbar,toolbar_fields{i}),'UserData'))==0;
               old_toolbar = setfield(old_toolbar,toolbar_fields{i},get(getfield(toolbar,toolbar_fields{i}),'UserData'));
            end;
            delete(getfield(toolbar,toolbar_fields{i}));
         end;
      end;
      %
      % delete uimenus
      %
      my_tools = findobj(fig_handle,'Tag','ToolsMenu')';
      my_files = findobj(fig_handle,'Tag','FileMenu')';
      my_edits = findobj(fig_handle,'Tag','EditMenu')';
      my_helps = findobj(fig_handle,'Tag','HelpMenu')';
      if isempty(my_files)==0;
         for i=1:size(my_files,2);
            delete(my_files(1,i));
         end;
      end;
      if isempty(my_tools)==0;
         for i=1:size(my_tools,2);
            delete(my_tools(1,i));
         end;
      end;
      if isempty(my_edits)==0;
         for i=1:size(my_edits,2);
            delete(my_edits(1,i));
         end;
      end;
      if isempty(my_helps)==0;
         for i=1:size(my_helps,2);
            delete(my_helps(1,i));
         end;
      end;
      old_myaxes = myaxes;
      %
      % dealing with legends and moving axes to match
      % with new toolbar
      %
      this_colorbar = findobj(fig_handle,'Type','axes','Tag','colorbar')';
      if isempty(this_colorbar)==0;
         if strcmp(get(this_colorbar,'Visible'),'on')==1;
            old_axes_handle = get(this_colorbar,'UserData');
            set(this_colorbar,'UserData',[]);
            myaxes = [myaxes this_colorbar];
         end;
      end;
      old_units = get(myaxes(1,1),'Units');
      set(myaxes(1,1),'Units','pixels');
      ax_pos = get(myaxes(1,1),'Position');
      set(myaxes(1,1),'Units',old_units);
      ref_point = ax_pos(1:2);
      num_rows = 1;
      for i=2:size(myaxes,2);
         old_units = get(myaxes(1,i),'Units');
         set(myaxes(1,i),'Units','pixels');
         ax_pos = get(myaxes(1,i),'Position');
         set(myaxes(1,i),'Units',old_units);
         new_point = ax_pos(1:2);
         if (new_point(1)==ref_point(1))&(new_point(2)<ref_point(2));
            num_rows = num_rows+1;
            ref_point = new_point;
         end;
      end;
      num_cols = ceil(size(myaxes,2)/num_rows);
      %
      % now we now the number of rows and columns of axes that exist
      % in the current figure. it remains to fix the axes such
      % they are in combination 40 pixels smaller in height
      %
      adj_height = 40/num_rows;
      count = 0;
      for i=1:num_rows;
         for j=1:num_cols;
            count = count+1;
            if count<=size(myaxes,2);
               %
               % fix all the in-between rows of axes in the graph
               %
               old_units = get(myaxes(1,count),'Units');
               set(myaxes(1,count),'Units','pixels');
               axpos = get(myaxes(1,count),'Position')+[0 (num_rows-i)*adj_height 0 adj_height];
               set(myaxes(1,count),'Units','normalized');
               if isempty(get(myaxes(1,count),'UserData'))==0;
                  myleg = get(myaxes(1,count),'UserData');
                  set(myleg,'Units','pixels');
                  legpos = get(myleg,'Position');
                  if (legpos(2)+legpos(4)<axpos(2)+axpos(4))&((axpos(4)+axpos(2))-(legpos(4)+legpos(2))<legpos(2)-axpos(2));
                     legpos = legpos+[0 (num_rows-i+1)*adj_height 0 0];
                  end;
                  set(myleg,'Units','normalized');
                  leg_ud = get(myleg,'UserData');
                  set(myleg,'UserData',leg_ud);
               end;
               set(myaxes(1,count),'Units',old_units);
            end;
         end;
      end;
      if isempty(this_colorbar)==0;
         if strcmp(get(this_colorbar,'Visible'),'on')==1;
            set(this_colorbar,'UserData',old_axes_handle);
         end;
      end;
      %
      % set up new toolbar
      %
      change_toolbar_fcn(old_myaxes);
      toolbar = get(fig_handle,'UserData');
      for i=1:size(toolbar_fields,1);
         if isfield(old_toolbar,toolbar_fields{i})==1;
            if (isempty(getfield(old_toolbar,toolbar_fields{i}))==0)&(strcmp(toolbar_fields{i},'saveas')==0)&(isfield(toolbar,toolbar_fields{i})==1)&(strcmp(toolbar_fields{i},'alignment')==0)&(strcmp(toolbar_fields{i},'about')==0);
               set(getfield(toolbar,toolbar_fields{i}),'UserData',getfield(old_toolbar,toolbar_fields{i}))
            end;
         end;
      end;
   else;
      this_axes = sort(findobj(fig_handle,'Type','axes')');
      if isempty(this_axes)==0
         my_axes = [];
         for j=1:size(this_axes,2);
            if strcmp(get(get(this_axes(1,j),'Title'),'string'),'')==0;
               my_axes = [my_axes this_axes(1,j)];
            end;
         end;
         if isempty(my_axes)==0;
            change_toolbar_fcn(my_axes);
         else;
            delete(fig_file);
            my_text = ['The file "' getfilename(fig_file) '" cannot be opened by Structural VAR''s FigEditor.'];
            about(my_text,'information','Invalid file...',120,350);
            return;
         end;
      end;
   end;
   set(fig_handle,'Menubar','none','Toolbar','none','Visible','on','Color',figcolor,'Position',pos,'Pointer','arrow');
else;
   my_tools = findobj(fig_handle,'Tag','ToolsMenu')';
   my_files = findobj(fig_handle,'Tag','FileMenu')';
   my_edits = findobj(fig_handle,'Tag','EditMenu')';
   my_helps = findobj(fig_handle,'Tag','HelpMenu')';
   if isempty(my_files)==0;
      for i=1:size(my_files,2);
         delete(my_files(1,i));
      end;
   end;
   if isempty(my_tools)==0;
      for i=1:size(my_tools,2);
         delete(my_tools(1,i));
      end;
   end;
   if isempty(my_edits)==0;
      for i=1:size(my_edits,2);
         delete(my_edits(1,i));
      end;
   end;
   if isempty(my_helps)==0;
      for i=1:size(my_helps,2);
         delete(my_helps(1,i));
      end;
   end;
   %
   % try to see if a toolbar from the stand-alone release
   % is hidden. if it is, it should be deleted
   %
   toolbar = get(fig_handle,'UserData');
   if (isempty(toolbar)==0)&(isfield(toolbar,'print')==1)&(ishandle(toolbar.print)==1)&(isfield(toolbar,'box1')==1)&(ishandle(toolbar.box1)==1);
      set(fig_handle,'ResizeFcn','');
      if isempty(get(toolbar.print,'UserData'))==0;
         axeshandles = get(toolbar.print,'UserData');
         if ishandle(axeshandles(1,1))==0;
            axeshandles = [];
         end;
      else;
         axeshandles = [];
      end;
      if isempty(axeshandles)==0;
         %
         % delete old toolbar
         %
         toolbar_fields = fieldnames(toolbar);
         b_3d = 0;
         for i=1:size(toolbar_fields,1);
            if ishandle(getfield(toolbar,toolbar_fields{i}))==1;
               if b_3d==0;
                  if strcmp(toolbar_fields{i},'rotate3d')==1;
                     b_3d = 1;
                  end;
               end;
               delete(getfield(toolbar,toolbar_fields{i}));
            end;
         end;
         %
         % dealing with legends and moving axes to match
         % with new toolbar
         %
         this_colorbar = findobj(fig_handle,'Type','axes','Tag','colorbar')';
         if isempty(this_colorbar)==0;
            if strcmp(get(this_colorbar,'Visible'),'on')==1;
               old_axes_handle = get(this_colorbar,'UserData');
               set(this_colorbar,'UserData',[]);
               axeshandles = [axeshandles this_colorbar];
            end;
         end;
         old_units = get(axeshandles(1,1),'Units');
         set(axeshandles(1,1),'Units','pixels');
         ax_pos = get(axeshandles(1,1),'Position');
         set(axeshandles(1,1),'Units',old_units);
         ref_point = ax_pos(1:2);
         num_rows = 1;
         for i=2:size(axeshandles,2);
            old_units = get(axeshandles(1,i),'Units');
            set(axeshandles(1,i),'Units','pixels');
            ax_pos = get(axeshandles(1,i),'Position');
            set(axeshandles(1,i),'Units',old_units);
            new_point = ax_pos(1:2);
            if (new_point(1)==ref_point(1))&(new_point(2)<ref_point(2));
               num_rows = num_rows+1;
               ref_point = new_point;
            end;
         end;
         num_cols = ceil(size(axeshandles,2)/num_rows);
         %
         % now we now the number of rows and columns of axes that exist
         % in the current figure. it remains to fix the axes such
         % they are in combination 40 pixels smaller in height
         %
         adj_height = 40/num_rows;
         count = 0;
         for i=1:num_rows;
            for j=1:num_cols;
               count = count+1;
               if count<=size(axeshandles,2);
                  %
                  % fix all the in-between rows of axes in the graph
                  %
                  old_units = get(axeshandles(1,count),'Units');
                  set(axeshandles(1,count),'Units','pixels');
                  axpos = get(axeshandles(1,count),'Position')+[0 (num_rows-i)*adj_height 0 adj_height];
                  set(axeshandles(1,count),'Units','normalized');
                  if isempty(get(axeshandles(1,count),'UserData'))==0;
                     myleg = get(axeshandles(1,count),'UserData');
                     set(myleg,'Units','pixels');
                     legpos = get(myleg,'Position');
                     if (legpos(2)+legpos(4)<axpos(2)+axpos(4))&((axpos(4)+axpos(2))-(legpos(4)+legpos(2))<legpos(2)-axpos(2));
                        legpos = legpos+[0 (num_rows-i+1)*adj_height 0 0];
                     end;
                     set(myleg,'Units','normalized');
                  end;
                  set(axeshandles(1,count),'Units',old_units);
                  if b_3d==0;
                     if curr_ini.ytick==1;
                        fixytix(axeshandles(1,count));
                     end;
                     if curr_ini.xtick==1;
                        fixxtix(axeshandles(1,count));
                     end;
                  end;
               end;
            end;
         end;
         if isempty(this_colorbar)==0;
            if strcmp(get(this_colorbar,'Visible'),'on')==1;
               set(this_colorbar,'UserData',old_axes_handle);
            end;
         end;
         %
         % delete any context menus and button down functions linked
         % with titles and labels
         %
         mylines = [];
         mypatches = [];
         mysurf = [];
         for i=1:size(axeshandles,2);
            set(axeshandles(1,i),'UIContextMenu','');
            set(get(axeshandles(1,i),'Title'),'UIContextMenu','','ButtonDownFcn','');
            set(get(axeshandles(1,i),'XLabel'),'UIContextMenu','','ButtonDownFcn','');
            set(get(axeshandles(1,i),'YLabel'),'UIContextMenu','','ButtonDownFcn','');
            set(get(axeshandles(1,i),'ZLabel'),'UIContextMenu','','ButtonDownFcn','');
            linehandles = findobj(axeshandles(1,i),'Type','line')';
            mylines = [mylines linehandles];
            patchhandles = findobj(axeshandles(1,i),'Type','patch')';
            mypatches = [mypatches patchhandles];
            mysurf = [mysurf findobj(axeshandles(1,i),'Type','surface')'];
         end;
         %
         % delete context menus linked with lines and patches
         %
         if isempty(mylines)==0;
            for j=1:size(mylines,2);
               if strcmp(get(mylines(1,j),'Tag'),'light')==0;
                  set(mylines(1,j),'UIContextMenu','');
               end;
            end;
         end;
         if isempty(mypatches)==0;
            for j=1:size(mypatches,2);
               set(mypatches(1,j),'UIContextMenu','');
            end;
         end;
         %
         % edit context menu's related to surfaces
         %
         if isempty(mysurf)==0;
            for j=1:size(mysurf,2);
               this_context = get(mysurf(1,j),'UIContextMenu');
               kids = sort(get(this_context,'Children')');
               num_del_kids = 0;
               for j1=1:size(kids,2);
                  if (strcmp(lower(get(kids(1,j1),'Label')),'cut')==1)|(strcmp(lower(get(kids(1,j1),'Label')),'copy')==1);
                     delete(kids(1,j1));
                     num_del_kids = num_del_kids+1;
                  end;
               end;
               if num_del_kids==size(kids,2);
                  set(mysurf(1,j),'UIContextMenu',[]);
               else;
                  set(mysurf(1,j),'UIContextMenu',this_context);
               end;
            end;
         end;
         set(fig_handle,'Menubar','figure','Toolbar','auto','DeleteFcn','drawnow');
      end;
   end;
   if strcmp(get(fig_handle,'Menubar'),'figure')==0;
      set(fig_handle,'Menubar','figure','Toolbar','auto');
   end;
   set(fig_handle,'Visible','on','Color',figcolor,'ResizeFcn','','Pointer','arrow');
end;

%
% end of showfig.m
%
