%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing text file               %
%                                                                %
%          Function: textgui                                     %
%                                                                %
%          Input:                                                %
%          		          textfile: file or text string            %
%                       figname: text string                     %
%                       position: 1x4 vector with positioning    %
%                          information                           %
%                       boxtext: text string                     %
%                       boxwidth: integer                        %
%                       display_copy: integer (optional)         %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        April 19, 2006                   %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function textgui(textfile,figname,position,boxtext,boxwidth,display_copy)

curr_ini = find_inisettings;

if nargin<6;
   display_copy = 1;
end;

if size(textfile,1)==1;
   if strcmp(getext(textfile),'.wk1')==1;
      [thisdata,thisname,thisdate] = wk1read_fcn(textfile);
      textfiletext = num2str(thisdata,'%17.10f');
      if isempty(thisname)==0;
         thisname = strrep(thisname,' ','            ');
      end;
      if isempty(thisdate)==0;
         paddthis = '';
         for i=1:size(thisdate,1);
            thisdate(i,:) = strrep(thisdate(i,:),' ',':');
            paddthis = strvcat(paddthis,'    ');
         end;
         thisname = [' DATE       ' thisname];
         textfiletext = [thisdate paddthis textfiletext];
      end;
      textfiletext = strvcat(thisname,textfiletext);
   elseif strcmp(getext(textfile),'.mat')==1;
      [thisdata,thisname,thisdate] = matread_fcn(textfile);
      textfiletext = num2str(thisdata);
      if isempty(thisname)==0;
         thisname = strrep(thisname,' ','            ');
      end;
      if isempty(thisdate)==0;
         paddthis = '';
         for i=1:size(thisdate,1);
            thisdate(i,:) = strrep(thisdate(i,:),' ',':');
            paddthis = strvcat(paddthis,'    ');
         end;
         thisname = [' DATE       ' thisname];
         textfiletext = [thisdate paddthis textfiletext];
      end;
      textfiletext = strvcat(thisname,textfiletext);
   elseif strcmp(getext(textfile),'.xls')==1;
      if matlabnumber>=6.0;
         [thisdata,thisname,thisdate] = xlsread_fcn(textfile);
         textfiletext = num2str(thisdata);
         if isempty(thisname)==0;
            thisname = strrep(thisname,' ','            ');
         end;
         if isempty(thisdate)==0;
            paddthis = '';
            for i=1:size(thisdate,1);
               thisdate(i,:) = strrep(thisdate(i,:),' ',':');
               paddthis = strvcat(paddthis,'    ');
            end;
            thisname = [' DATE       ' thisname];
            textfiletext = [thisdate paddthis textfiletext];
         end;
         textfiletext = strvcat(thisname,textfiletext);
      else;
         textfiletext = 'You need MatLab version 6.x or later to read Excel spreadsheets.';
      end;
   else;
      textfiletext = readtext(textfile);
   end;
else;
   textfiletext = textfile;
end;

if iscellstr(textfiletext)==1;
   if strcmp(strtrim(textfiletext{max(size(textfiletext))}),'')==0;
      textfiletext{max(size(textfiletext))+1} = ' ';
   end;
else;
   if strcmp(strtrim(textfiletext(size(textfiletext,1),:)),'')==0;
      textfiletext = strvcat(textfiletext,' ');
   end;
end;

boxpos = [2 2 position(3)-2 position(4)-10];

listpos = [15 54 position(3)-30 position(4)-78];

buttonpos = [position(3)-105 20 90 20];

textdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'FileName','textgui.m', ...
   'MenuBar','none', ...
   'PaperUnits','points', ...
   'Units','pixels', ...
   'Position',position, ...
   'Tag','FigParent', ...
   'DoubleBuffer','on', ...
   'Resize','on', ...
   'ResizeFcn','textgui_resize_fcn', ...
   'Name',figname, ...
   'NumberTitle','off', ...
   'Visible','off', ...
   'CloseRequestFcn','closegui', ...
   'ToolBar','none');

if matlabnumber>=7.0;
   set(textdlg,'DockControl','off');
end;

%
% Outer axis
%

mytext.box = axesbox(boxpos,boxtext,boxwidth,[0.5 1]);
ud.boxtext = boxtext;
ud.boxwidth = boxwidth;

mytext.icon = uicontrol('Units','pixels','Position',[0 0 1 1],'Visible','off');

%
% Listbox control with mytext file text
%

mytext.text = uicontrol('Units','pixels', ...
   'BackgroundColor',curr_ini.text_backgroundcolor, ...
   'ForegroundColor',curr_ini.text_color, ...
   'Position',listpos, ...
   'FontSize',curr_ini.text_fontsize, ...
   'FontName',curr_ini.text_fontname, ...
   'FontWeight',curr_ini.text_fontweight, ...
   'FontAngle',curr_ini.text_fontangle, ...
   'FontUnits',curr_ini.text_fontunits, ...
   'Style','listbox', ...
   'Enable','inactive', ...
   'UserData',ud, ...
   'Max',2, ...
   'HorizontalAlignment','center', ...
   'String',textfiletext, ...
   'Tag','TextDlg',...
   'Value',[]);

%
% Copy to clipboard button
%

if (display_copy==1)&(strcmp(computer,'PCWIN')==1);
   mytext.copy = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ForegroundColor',[0 0 0], ...
      'Position',[20 20 90 20], ...
      'String','Copy', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'CallBack','textgui_copy_fcn', ...
      'Enable','on', ...
      'Tag','Done');
end;

%
% Done button
%

mytext.done = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'ForegroundColor',[0 0 0], ...
   'Position',buttonpos, ...
   'String','Done', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'CallBack','closegui', ...
   'Enable','on', ...
   'UserData','waiting', ...
   'Tag','Done');

set(textdlg,'UserData',mytext, ...
   'HandleVisibility','callback');

if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
   prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(textdlg,'Name') ' ' fix_filepath([pwd '\icons\text.ico'])];
   dos(prog);
   if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
      %
      % now we need to determine the pid
      %
      pid = getpid('seticon');
      set(mytext.icon,'UserData',pid);
   end;
end;
set(textdlg,'Visible','on');
drawnow;
if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
   drawnow;
   prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(textdlg,'Name') ' 1'];
   dos(prog);
   drawnow;
elseif matlabnumber>=7;
   uicontrol(mytext.done);
end;

waitfor(textdlg,'waitstatus','inactive');
%uiwait(textdlg);

killguipid(textdlg);
drawnow;

%
% end of textgui.m
%
