%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing about dialog            %
%                                                                %
%          Function: about                                       %
%                                                                %
%          Input:                                                %
%                       mytext: text string                      %
%          		          myimage: image name                      %
%                       mylabel: text string                     %
%                       width: dialog width in pixels            %
%                       height: dialog height in pixels          %
%                       s_cancel: boolean for showing a          %
%                          Cancel button                         %
%                                                                %
%          Output:                                               %
%          		          fout: handle                             %
%                                                                %
%          This version:        May 15, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function fout = waitdlg(mytext,myimage,mylabel,width,height,s_cancel)

if nargin==2;
   mylabel = 'Waiting';
   selector = 'init';
   width = 350;
   height = 124;
elseif nargin==3;
   selector = 'init';
   width = 350;
   height = 124;
elseif nargin==4;
   selector = 'init';
   height = 124;
elseif nargin==5;
   selector = 'init';
elseif nargin==6;
   selector = 'init';
else;
   selector = 'exit';
end;
if nargin<6;
   s_cancel = 0;
end;

if strcmp(selector,'init')==1;
   mycons = getstoredimages;
   curr_ini = find_inisettings;
   if curr_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   %
   if strcmp(myimage,'information')==1;
      mylogo = mycons.information_image;
   elseif strcmp(myimage,'question')==1;
      mylogo = mycons.question_image;
   elseif strcmp(myimage,'warning')==1;
      mylogo = mycons.warning_image;
   elseif strcmp(myimage,'error')==1;
      mylogo = mycons.error_image;
   elseif strcmp(myimage,'borg')==1;
      mylogo = mycons.borg_image;
   elseif strcmp(myimage,'movie')==1;
      mylogo = mycons.movie_image;
   elseif strcmp(myimage,'bootstrap')==1;
      mylogo = mycons.bootstrap_image;
   elseif strcmp(myimage,'delete')==1;
      mylogo = mycons.deletebig_image;
   elseif strcmp(myimage,'latex')==1;
      mylogo = mycons.latex_image;
   elseif strcmp(myimage,'postscript')==1;
      mylogo = mycons.postscript_image;
   elseif strcmp(myimage,'pdf')==1;
      mylogo = mycons.pdf_image;
   elseif strcmp(myimage,'explore')==1;
      mylogo = mycons.explore_image;
   elseif strcmp(myimage,'forecast')==1;
      mylogo = mycons.forecastbig_image;
   else;
      mylogo = mycons.logo_image;
   end;
   mylogo = mirrorimage(maketrans(mylogo,[160 160 164],bgcolor));
else;
   waitgui = get(0,'CurrentFigure');
   waitf = get(waitgui,'UserData');
end;

scrsz = get(0,'ScreenSize');

switch selector;
   case 'init'
   waitgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'FileName','waitdlg.m', ...
      'MenuBar','none', ...
      'Units','pixels', ...
      'Position',[(scrsz(3)-width)/2 (scrsz(4)-height)/2 width height], ...
      'Tag','Figwait', ...
      'Resize','off', ...
      'Name',mylabel, ...
      'NumberTitle','off', ...
      'CloseRequestFcn','waitdlg exit', ...
      'Visible','off', ...
      'WindowStyle','modal', ...
      'ToolBar','none');

   if matlabnumber>=7.0;
      set(waitgui,'DockControl','off');
   end;

   imageaxes = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[10 height/2 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',mylogo,'Clipping','off','Parent',imageaxes);

   waitf.text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[60 20 width-62 height-24], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'UserData','working', ...
         'String',mytext, ...
         'Tag','Text');

   if s_cancel==1;
      waitf.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[(width-70)/2 12 70 20], ...
         'Style','pushbutton', ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Callback','set(gcbo,''UserData'',''cancel'')', ...
         'Enable','on', ...
         'UserData','', ...
         'Tag','CancelButton');
   end;

   set(waitgui,'UserData',waitf,...
      'HandleVisibility','callback');

   if (iswinnt==1)&(iscompiled==1)&(curr_ini.noicon==1);
      set(waitgui,'WindowStyle','normal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(waitgui,'Name') ' NULL'];
      dos(prog);
      wait_fcn(curr_ini.delay);
      pos = get(waitgui,'Position');
      set(waitgui,'Position',[0 0 1 1]);
   end;
   %
   set(waitgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1);
      if curr_ini.noicon==1;
         drawnow;
         set(waitgui,'WindowStyle','modal');
         prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(waitgui,'Name') ' NULL'];
         dos(prog);
         wait_fcn(curr_ini.delay);
         set(waitgui,'Position',pos);
      end;
      %
      drawnow;
      drawnow;
      if curr_ini.noicon==1;
         set(waitgui,'Position',pos);
      end;
   end;

case 'exit'
   if strcmp(get(waitf.text,'UserData'),'done')==1;
      delete(waitgui);
   end;
end;

if nargout==1;
   fout = waitgui;
end;

if strcmp(selector,'init')==1;
   drawnow;
   drawnow;
   if s_cancel==1;
      if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
         drawnow;
         prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(waitgui,'Name') ' 1'];
         dos(prog);
         drawnow;
      elseif matlabnumber>=7;
         uicontrol(waitf.cancel);
      end;
   end;
end;

%
% end of about.m
%
